@@ -1,9 +1,10 @@
+
 /***************************************************************************
- *                            RasMol 2.7.2.1.1                             *
+ *                               RasMol 2.7.3                              *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                            26 January 2004                              *
+ *                             6 February 2005                             *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -25,12 +26,19 @@
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
+ *                   RasMol 2.7.3   Feb 05                                 *
+ *                                                                         *
+ *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
+ *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
+ *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
+ *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
+ *of Energy.                                                               *
  *                                                                         *
  *                    and Incorporating Translations by                    *
  *  Author                               Item                      Language*
- *  Isabel Servn Martnez,                                                *
- *  Jos Miguel Fernndez Fernndez      2.6   Manual              Spanish *
- *  Jos Miguel Fernndez Fernndez      2.7.1 Manual              Spanish *
+ *  Isabel Servan Martinez,                                                *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
  *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
  *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
@@ -39,35 +47,12 @@
  *                             This Release by                             *
  * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2001               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2005               *
  *                                                                         *
- * Please read the file NOTICE for important notices which apply to this   *
- * package. If you are not going to make changes to RasMol, you are not    *
- * only permitted to freely make copies and distribute them, you are       *
- * encouraged to do so, provided you do the following:                     *
- *   * 1. Either include the complete documentation, especially the file   *
- *     NOTICE, with what you distribute or provide a clear indication      *
- *     where people can get a copy of the documentation; and               *
- *   * 2. Please give credit where credit is due citing the version and    *
- *     original authors properly; and                                      *
- *   * 3. Please do not give anyone the impression that the original       *
- *     authors are providing a warranty of any kind.                       *
- *                                                                         *
- * If you would like to use major pieces of RasMol in some other program,  *
- * make modifications to RasMol, or in some other way make what a lawyer   *
- * would call a "derived work", you are not only permitted to do so, you   *
- * are encouraged to do so. In addition to the things we discussed above,  *
- * please do the following:                                                *
- *   * 4. Please explain in your documentation how what you did differs    *
- *     from this version of RasMol; and                                    *
- *   * 5. Please make your modified source code available.                 *
- *                                                                         *
- * This version of RasMol is not in the public domain, but it is given     *
- * freely to the community in the hopes of advancing science. If you make  *
- * changes, please make them in a responsible manner, and please offer us  *
- * the opportunity to include those changes in future versions of RasMol.  *
+ *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
+ *Please read the file NOTICE for important notices which apply to this    *
+ *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
-
 /* abstree.c
  */
 
@@ -1304,15 +1289,15 @@ void ResetSymbolTable( void )
 
 double CalcDistance( RAtom __far *atm1, RAtom __far *atm2 )
 {
-    register Long dx,dy,dz;
+    register double dx,dy,dz;
     register double dist2;
 
-    dx = atm1->xorg - atm2->xorg + atm1->fxorg - atm2->fxorg;
-    dy = atm1->yorg - atm2->yorg + atm1->fyorg - atm2->fyorg;
-    dz = atm1->zorg - atm2->zorg + atm1->fzorg - atm2->fzorg;
-    if( dx || dy || dz )
+    dx = (double)(atm1->xorg - atm2->xorg + atm1->fxorg - atm2->fxorg);
+    dy = (double)(atm1->yorg - atm2->yorg + atm1->fyorg - atm2->fyorg);
+    dz = (double)(atm1->zorg - atm2->zorg + atm1->fzorg - atm2->fzorg);
+    if( dx != 0.0 || dy != 0.0 || dz != 0.0 )
     {   dist2 = dx*dx + dy*dy + dz*dz;
-        return( sqrt(dist2)/250.0 );
+        return( sqrt(dist2/62500.) );
     } else return 0.0;
 }
 
@@ -1368,7 +1353,7 @@ double CalcTorsion( RAtom __far *atm1, RAtom __far *atm2,
     ay = atm2->yorg - atm1->yorg + atm2->fyorg - atm1->fyorg
          + (double)(atm2->ytrl - atm1->ytrl)/40.;
     az = atm2->zorg - atm1->zorg + atm2->fzorg - atm1->fzorg
-         - (double)(atm2->ztrl - atm1->ztrl)/40.;
+         + (double)(atm2->ztrl - atm1->ztrl)/40.;
     if( !ax && !ay && !az )
         return 0.0;
 
@@ -1377,7 +1362,7 @@ double CalcTorsion( RAtom __far *atm1, RAtom __far *atm2,
     by = atm3->yorg - atm2->yorg + atm3->fyorg - atm2->fyorg
          + (double)(atm3->ytrl - atm2->ytrl)/40.;
     bz = atm3->zorg - atm2->zorg + atm3->fzorg - atm2->fzorg
-         - (double)(atm3->ztrl - atm2->ztrl)/40.;
+         + (double)(atm3->ztrl - atm2->ztrl)/40.;
     if( !bx && !by && !bz )
         return 0.0;
 
@@ -1386,7 +1371,7 @@ double CalcTorsion( RAtom __far *atm1, RAtom __far *atm2,
     cy = atm4->yorg - atm3->yorg + atm4->fyorg - atm3->fyorg
          + (double)(atm4->ytrl - atm3->ytrl)/40.;
     cz = atm4->zorg - atm3->zorg + atm4->fzorg - atm3->fzorg
-         - (double)(atm4->ztrl - atm3->ztrl)/40.;
+         + (double)(atm4->ztrl - atm3->ztrl)/40.;
     if( !cx && !cy && !cz )
         return 0.0;
 
@@ -1582,7 +1567,7 @@ char *DescribeObj( AtomRef *ptr, Selection select )
       y = (double)(ptr->atm->yorg + ptr->atm->fyorg + OrigCY)/250.0
          +(double)(ptr->atm->ytrl)/10000.0;
       z = (double)(ptr->atm->zorg + ptr->atm->fzorg + OrigCZ)/250.0
-         -(double)(ptr->atm->ztrl)/10000.0;
+         +(double)(ptr->atm->ztrl)/10000.0;
 
 #ifdef INVERT
       sprintf(eptr, "\n  Coordinates: %9.3f %9.3f %9.3f\n",x,-y,-z);
