@@ -1,9 +1,10 @@
+
 /***************************************************************************
- *                            RasMol 2.7.2.1.1                             *
+ *                               RasMol 2.7.3                              *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                            26 January 2004                              *
+ *                             6 February 2005                             *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -25,12 +26,19 @@
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
+ *                   RasMol 2.7.3   Feb 05                                 *
+ *                                                                         *
+ *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
+ *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
+ *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
+ *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
+ *of Energy.                                                               *
  *                                                                         *
  *                    and Incorporating Translations by                    *
  *  Author                               Item                      Language*
- *  Isabel Servn Martnez,                                                *
- *  Jos Miguel Fernndez Fernndez      2.6   Manual              Spanish *
- *  Jos Miguel Fernndez Fernndez      2.7.1 Manual              Spanish *
+ *  Isabel Servan Martinez,                                                *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
  *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
  *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
@@ -39,35 +47,12 @@
  *                             This Release by                             *
  * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2001               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2005               *
  *                                                                         *
- * Please read the file NOTICE for important notices which apply to this   *
- * package. If you are not going to make changes to RasMol, you are not    *
- * only permitted to freely make copies and distribute them, you are       *
- * encouraged to do so, provided you do the following:                     *
- *   * 1. Either include the complete documentation, especially the file   *
- *     NOTICE, with what you distribute or provide a clear indication      *
- *     where people can get a copy of the documentation; and               *
- *   * 2. Please give credit where credit is due citing the version and    *
- *     original authors properly; and                                      *
- *   * 3. Please do not give anyone the impression that the original       *
- *     authors are providing a warranty of any kind.                       *
- *                                                                         *
- * If you would like to use major pieces of RasMol in some other program,  *
- * make modifications to RasMol, or in some other way make what a lawyer   *
- * would call a "derived work", you are not only permitted to do so, you   *
- * are encouraged to do so. In addition to the things we discussed above,  *
- * please do the following:                                                *
- *   * 4. Please explain in your documentation how what you did differs    *
- *     from this version of RasMol; and                                    *
- *   * 5. Please make your modified source code available.                 *
- *                                                                         *
- * This version of RasMol is not in the public domain, but it is given     *
- * freely to the community in the hopes of advancing science. If you make  *
- * changes, please make them in a responsible manner, and please offer us  *
- * the opportunity to include those changes in future versions of RasMol.  *
+ *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
+ *Please read the file NOTICE for important notices which apply to this    *
+ *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
-
 /* cmndline.c
  */
 
@@ -638,18 +623,58 @@ void SetMouseMode( int mode )
 
 
 static void PerformMouseFunc( int func, int delta, int max )
-{
+{   Real xcomp, ycomp, zcomp;
+    int  dist;
+    
     switch( func )
-    {   case(MM_ROTX):  WrapDial( DialRX, (Real)(2*delta)/max );
-                        ReDrawFlag |= RFRotateX;
+    {   case(MM_ROTX):  if ( (RotMode == RotBond) && BondSelected) {
+                          WrapDial( DialBRot, (Real)(2*delta)/max );
+                        } else {
+                          dist = PointX-XRange/2;
+                          if (dist < -XRange/8) {
+                            dist += XRange/8;
+                            dist *= 2;
+                            if (dist < -XRange/2) dist=-XRange/2;
+                          } else {
+                            dist -= XRange/8;
+                            if (dist < 0 ) dist = 0;
+                            dist *=2;
+                            if (dist > XRange/2) dist = XRange/2;
+                          }
+                          xcomp = (Real)(delta*(XRange/2-AbsFun(dist)))/((Real)(XRange/2));
+                          zcomp = (Real)(delta*dist)/((Real)(XRange/2));
+                          WrapDial( DialRX, 2*xcomp/(Real)max );
+                          WrapDial( DialRZ, 2*zcomp/(Real)max );
+                         /* WrapDial( DialRX, (Real)(2*delta)/max ); */
+                        }
+                        ReDrawFlag |= RFRotateX|RFRotateZ;
                         break;
                         
         case(MM_ROTY):  if ( (RotMode == RotBond) && BondSelected) {
                           WrapDial( DialBRot, (Real)(2*delta)/max );
                         } else {
-                          WrapDial( DialRY, (Real)(2*delta)/max );
+                          dist = PointY-YRange/2;
+                          if (dist < -YRange/8) {
+                            dist += YRange/8;
+                            dist *= 2;
+                            if (dist < -YRange/2) dist=-YRange/2;
+                          } else {
+                            dist -= YRange/8;
+                            if (dist < 0 ) dist = 0;
+                            dist *=2;
+                            if (dist > YRange/2) dist = YRange/2;
+                          }
+                          ycomp = (Real)(delta*(YRange/2-AbsFun(dist)))/((Real)(YRange/2));
+#ifdef INVERT
+                          zcomp = (Real)(delta*dist)/((Real)(YRange/2));
+#else
+                          zcomp = (Real)(-delta*dist)/((Real)(YRange/2));
+#endif
+                          WrapDial( DialRY, 2*ycomp/(Real)max );
+                          WrapDial( DialRZ, 2*zcomp/(Real)max );
+                        /* WrapDial( DialRY, (Real)(2*delta)/max ); */
                         }
-                        ReDrawFlag |= RFRotateY;
+                        ReDrawFlag |= RFRotateY|RFRotateZ;
                         break;
                         
         case(MM_ROTZ):  WrapDial( DialRZ, (Real)(2*delta)/max );
@@ -661,11 +686,11 @@ static void PerformMouseFunc( int func, int delta, int max )
                         break;
                         
         case(MM_TRNX):  ClampDial( DialTX, (Real)delta/max );
-                        ReDrawFlag |= RFTransX;
+                        ReDrawFlag |= RFTransX|RFTransZ;
                         break;
 
         case(MM_TRNY):  ClampDial( DialTY, (Real)delta/max );
-                        ReDrawFlag |= RFTransY;
+                        ReDrawFlag |= RFTransY|RFTransZ;
                         break;
 
         case(MM_CLIP):  ClampDial( DialSlab, (Real)delta/max );
