@@ -1,9 +1,10 @@
+
 /***************************************************************************
- *                            RasMol 2.7.2.1.1                             *
+ *                               RasMol 2.7.3                              *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                            26 January 2004                              *
+ *                             6 February 2005                             *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -25,12 +26,19 @@
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
+ *                   RasMol 2.7.3   Feb 05                                 *
+ *                                                                         *
+ *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
+ *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
+ *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
+ *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
+ *of Energy.                                                               *
  *                                                                         *
  *                    and Incorporating Translations by                    *
  *  Author                               Item                      Language*
- *  Isabel Servn Martnez,                                                *
- *  Jos Miguel Fernndez Fernndez      2.6   Manual              Spanish *
- *  Jos Miguel Fernndez Fernndez      2.7.1 Manual              Spanish *
+ *  Isabel Servan Martinez,                                                *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
  *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
  *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
@@ -39,35 +47,12 @@
  *                             This Release by                             *
  * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2001               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2005               *
  *                                                                         *
- * Please read the file NOTICE for important notices which apply to this   *
- * package. If you are not going to make changes to RasMol, you are not    *
- * only permitted to freely make copies and distribute them, you are       *
- * encouraged to do so, provided you do the following:                     *
- *   * 1. Either include the complete documentation, especially the file   *
- *     NOTICE, with what you distribute or provide a clear indication      *
- *     where people can get a copy of the documentation; and               *
- *   * 2. Please give credit where credit is due citing the version and    *
- *     original authors properly; and                                      *
- *   * 3. Please do not give anyone the impression that the original       *
- *     authors are providing a warranty of any kind.                       *
- *                                                                         *
- * If you would like to use major pieces of RasMol in some other program,  *
- * make modifications to RasMol, or in some other way make what a lawyer   *
- * would call a "derived work", you are not only permitted to do so, you   *
- * are encouraged to do so. In addition to the things we discussed above,  *
- * please do the following:                                                *
- *   * 4. Please explain in your documentation how what you did differs    *
- *     from this version of RasMol; and                                    *
- *   * 5. Please make your modified source code available.                 *
- *                                                                         *
- * This version of RasMol is not in the public domain, but it is given     *
- * freely to the community in the hopes of advancing science. If you make  *
- * changes, please make them in a responsible manner, and please offer us  *
- * the opportunity to include those changes in future versions of RasMol.  *
+ *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
+ *Please read the file NOTICE for important notices which apply to this    *
+ *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
-
 /* langsel.c
  */
 
@@ -525,6 +510,7 @@ static langstr langstrs[] = {
   { "Ribbons",                                         StrMRibbons, English,0},
   { "Strands",                                         StrMStrands, English,3},
   { "Cartoons",                                        StrMCartoon, English,0},
+  { "Molecular Surface",                               StrMMolSurf, English,0},
 
   { "Alambre",                                         StrMWirefr,  Spanish,0},
   { "Esqueleto",                                       StrMBackbn,  Spanish,0},
@@ -534,6 +520,7 @@ static langstr langstrs[] = {
   { "Cintas",                                          StrMRibbons, Spanish,0},
   { "Hebras",                                          StrMStrands, Spanish,0},
   { "Dibujo",                                          StrMCartoon, Spanish,0},
+  { "Superficie Molecular",                            StrMMolSurf, Spanish,11},
 
   { "Fil",                                             StrMWirefr,  French,0},
   { "Squelette",                                       StrMBackbn,  French,0},
@@ -543,6 +530,7 @@ static langstr langstrs[] = {
   { "Rubans",                                          StrMRibbons, French,0},
   { "Tresses",                                         StrMStrands, French,0},
   { "Ebauches",                                        StrMCartoon, French,5},
+  { "Surface Molcular",                               StrMMolSurf, French,8},
 
   { "Fildiferro",                                      StrMWirefr,  Italian,0},
   { "Scheletro",                                       StrMBackbn,  Italian,0},
@@ -552,6 +540,7 @@ static langstr langstrs[] = {
   { "Nastri",                                          StrMRibbons, Italian,0},
   { "Fili",                                            StrMStrands, Italian,0},
   { "Vignetta",                                        StrMCartoon, Italian,0},
+  { "Superficie Molecolare",                           StrMMolSurf, Italian,11},
 
   { "Monochrome",                                      StrMMonochr, English,0},
   { "CPK",                                             StrMCPK,     English,0},
@@ -877,6 +866,7 @@ static langstr langstrs[] = {
   { "&Ribbons",                                        StrMRibbons, English,0},
   { "Str&ands",                                        StrMStrands, English,3},
   { "&Cartoons",                                       StrMCartoon, English,0},
+  { "&Molecular Surface",                              StrMMolSurf, English,0},  
 
   { "&Alambre",                                        StrMWirefr,  Spanish,0},
   { "&Esqueleto",                                      StrMBackbn,  Spanish,0},
@@ -886,6 +876,7 @@ static langstr langstrs[] = {
   { "&Cintas",                                         StrMRibbons, Spanish,0},
   { "&Hebras",                                         StrMStrands, Spanish,0},
   { "&Dibujo",                                         StrMCartoon, Spanish,0},
+  { "Superficie &Molecular",                           StrMMolSurf, Spanish,11},
 
   { "&Fil",                                            StrMWirefr,  French,0},
   { "&Squelette",                                      StrMBackbn,  French,0},
@@ -895,6 +886,7 @@ static langstr langstrs[] = {
   { "&Ribbons",                                        StrMRibbons, French,0},
   { "&Tresses",                                        StrMStrands, French,0},
   { "Ebauc&hes",                                       StrMCartoon, French,5},
+  { "Surface &Molcular",                              StrMMolSurf, French,8},
 
   { "&Fildiferro",                                     StrMWirefr,  Italian,0},
   { "&Scheletro",                                      StrMBackbn,  Italian,0},
@@ -904,6 +896,7 @@ static langstr langstrs[] = {
   { "&Nastri",                                         StrMRibbons, Italian,0},
   { "&Fili",                                           StrMStrands, Italian,0},
   { "&Vignetta",                                       StrMCartoon, Italian,0},
+  { "Superficie &Molecolare",                          StrMMolSurf, Italian,11},
 
   { "&Monochrome",                                     StrMMonochr, English,0},
   { "&CPK",                                            StrMCPK,     English,0},
@@ -1153,7 +1146,19 @@ static langstr langstrs[] = {
   
   { "Nome documento PDB:",                             StrPrmtPDB,  Italian,0},
   { "Nome documento immagine:",                        StrPrmtImg,  Italian,0},
-  { "Nome documento molecola:",                        StrPrmtMol,  Italian,0}
+  { "Nome documento molecola:",                        StrPrmtMol,  Italian,0},
+
+  { "Warning: ",                                       StrWarn,     English,0},
+  { "Cuidado: ",                                       StrWarn,     Spanish,0},
+  { "Avertissement: ",                                 StrWarn,     French,0},
+  { "Attenzione: ",                                    StrWarn,     Italian,0},
+
+  { "Chain",                                           StrChain,    English,0},
+  { "Cadena",                                          StrChain,    Spanish,0},
+  { "Chane",                                          StrChain,    French,0},
+  { "Catena",                                          StrChain,    Italian,0}
+
+
 
   
 };
