@@ -1,9 +1,10 @@
+
 /***************************************************************************
- *                            RasMol 2.7.2.1.1                             *
+ *                               RasMol 2.7.3                              *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                            26 January 2004                              *
+ *                             6 February 2005                             *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -25,12 +26,19 @@
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
+ *                   RasMol 2.7.3   Feb 05                                 *
+ *                                                                         *
+ *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
+ *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
+ *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
+ *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
+ *of Energy.                                                               *
  *                                                                         *
  *                    and Incorporating Translations by                    *
  *  Author                               Item                      Language*
- *  Isabel Servn Martnez,                                                *
- *  Jos Miguel Fernndez Fernndez      2.6   Manual              Spanish *
- *  Jos Miguel Fernndez Fernndez      2.7.1 Manual              Spanish *
+ *  Isabel Servan Martinez,                                                *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
  *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
  *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
@@ -39,35 +47,12 @@
  *                             This Release by                             *
  * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2001               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2005               *
  *                                                                         *
- * Please read the file NOTICE for important notices which apply to this   *
- * package. If you are not going to make changes to RasMol, you are not    *
- * only permitted to freely make copies and distribute them, you are       *
- * encouraged to do so, provided you do the following:                     *
- *   * 1. Either include the complete documentation, especially the file   *
- *     NOTICE, with what you distribute or provide a clear indication      *
- *     where people can get a copy of the documentation; and               *
- *   * 2. Please give credit where credit is due citing the version and    *
- *     original authors properly; and                                      *
- *   * 3. Please do not give anyone the impression that the original       *
- *     authors are providing a warranty of any kind.                       *
- *                                                                         *
- * If you would like to use major pieces of RasMol in some other program,  *
- * make modifications to RasMol, or in some other way make what a lawyer   *
- * would call a "derived work", you are not only permitted to do so, you   *
- * are encouraged to do so. In addition to the things we discussed above,  *
- * please do the following:                                                *
- *   * 4. Please explain in your documentation how what you did differs    *
- *     from this version of RasMol; and                                    *
- *   * 5. Please make your modified source code available.                 *
- *                                                                         *
- * This version of RasMol is not in the public domain, but it is given     *
- * freely to the community in the hopes of advancing science. If you make  *
- * changes, please make them in a responsible manner, and please offer us  *
- * the opportunity to include those changes in future versions of RasMol.  *
+ *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
+ *Please read the file NOTICE for important notices which apply to this    *
+ *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
-
 /* molecule.c
  $Log: molecule.c,v $
  Revision 1.1  2004/05/07 19:46:16  yaya
@@ -133,6 +118,7 @@
 #include "transfor.h"
 #include "render.h"
 #include "langsel.h"
+#include "repres.h"
 #include "graphics.h"
 
 #define HBondPool   32
@@ -145,10 +131,16 @@
 
 #define Cos70Deg     0.34202014332567
 
-#define MaxHBondDist   ((Long)300*300)
-#define MaxBondDist    ((Long)475*475)
-#define MinBondDist    ((Long)100*100)
-#define AbsMaxBondDist 600
+#define MaxHBondDist   ((int)300)
+#define MaxBondDist    ((int)475)
+#define MinBondDist    ((int)100)
+
+#define MaxHBondDsq    ((Long)(MaxHBondDist*MaxHBondDist))
+#define MaxBondDsq     ((Long)(MaxBondDist*MaxBondDist))
+#define MinBondDsq     ((Long)(MinBondDist*MinBondDist))
+#define AbsMaxBondDist 600      /* 2.4 Angstroms */
+#define AbsMaxAtomRad  750      /* 3.0 Angstroms */
+#define AbsMaxAtomDiam AbsMaxAtomRad*2
 
 #ifdef APPLEMAC
 #define AllocSize   256
@@ -371,6 +363,7 @@ void CreateChain( int ident )
         CurMolecule->slist = (void __far*)0;
         CurMolecule->hlist = (void __far*)0;
         CurMolecule->blist = (void __far*)0;
+        CurMolecule->sblist = (void __far*)0;
         CurMolecule->clist = (void __far*)0;
         Database = CurMolecule;
     }
@@ -938,9 +931,10 @@ int NewAtomType( char *ptr )
 
 int SimpleAtomType( char *type )
 {
-    char name[4];
+    char name[5];
 
     name[2] = name[3] = ' ';
+    name[4] = '\0';
     if( type[1] && (type[1]!=' ') )
     {   name[0] = ToUpper(type[0]);
         name[1] = ToUpper(type[1]);
@@ -954,9 +948,10 @@ int SimpleAtomType( char *type )
 
 int ComplexAtomType( char *ptr )
 {
-    static char name[4];
+    char name[5];
     register int i;
 
+    name[4] ='\0';
     if( isdigit(ptr[1]) )
     {   /* IDATM PDB files! */
         name[0] = ' ';
@@ -1224,12 +1219,62 @@ Bond __far *ProcessBond( RAtom __far *src, RAtom __far *dst, int flag )
     ptr->aradius = 0;
     ptr->iarad = 0;
     ptr->col = 0;
+
     ptr->altl = '\0';
     if (src && src->altl != '\0' && src->altl != ' ') ptr->altl = src->altl;
     if (dst && dst->altl != '\0' && dst->altl != ' ') ptr->altl = dst->altl;
 
     return ptr;
 }
+SurfBond __far *ProcessSurfBond( RAtom __far *src, RAtom __far *dst )
+{
+    register SurfBond __far *ptr;
+    register int i;
+    register Long lx, ly, lz, lxyzsq;
+    register Long xrad1, xrad2, wpsq;
+
+    DrawSurf = True;
+
+    if( !(ptr = FreeSurfBond) )
+    {   MemSize += BondPool*sizeof(SurfBond);
+        ptr = (SurfBond __far *)_fmalloc( BondPool*sizeof(SurfBond) );
+        if( !ptr ) FatalDataError(MsgStrs[StrMalloc]);
+        RegisterAlloc( ptr );
+        for( i=1; i<BondPool; i++ )
+        {   ptr->sbnext = FreeSurfBond;
+            FreeSurfBond = ptr++;
+        } 
+    } else FreeSurfBond = ptr->sbnext;
+
+    ptr->srcatom = src;
+    ptr->dstatom = dst;
+    ptr->col = 0;
+
+    ptr->altl = '\0';
+    if (src && src->altl != '\0' && src->altl != ' ') ptr->altl = src->altl;
+    if (dst && dst->altl != '\0' && dst->altl != ' ') ptr->altl = dst->altl;
+    lx = src->xorg+src->fxorg-dst->xorg-dst->fxorg;
+    ly = src->yorg+src->fyorg-dst->yorg-dst->fyorg;
+    lz = src->zorg+src->fzorg-dst->zorg-dst->fzorg;
+    lxyzsq = lx*lx + ly*ly + lz*lz;
+    ptr->sxyz = (Long)(sqrt((double)lxyzsq)+.5);
+    xrad1 = src->radius;
+    xrad2 = dst->radius;
+    ptr->u1 = ((ptr->sxyz)+
+      (((((xrad1+xrad2+(ProbeRadius+ProbeRadius))*
+      (xrad1-xrad2)))/ptr->sxyz))+1)>>1;
+    /* if (ptr->u1 > ptr->sxyz) ptr->u1 = ptr->sxyz; */
+    ptr->u2 = ptr->sxyz-ptr->u1;
+    wpsq = ((((xrad1+ProbeRadius))*((xrad1+ProbeRadius))))
+      -ptr->u1*ptr->u1;
+    if (wpsq < 0 ) wpsq = 0;
+    ptr->wp = (Long)rint(sqrt((double)wpsq));
+    ptr->t1 = (ptr->u1*xrad1)/(xrad1+ProbeRadius);
+    ptr->t2 = (ptr->u2*xrad2)/(xrad2+ProbeRadius);
+    ptr->w1 = (ptr->wp*xrad1)/(xrad1+ProbeRadius);
+    ptr->w2 = (ptr->wp*xrad2)/(xrad2+ProbeRadius);
+    return ptr;
+}
 
 static void CreateHydrogenBond( RAtom __far *srcCA, RAtom __far *dstCA,
                                 RAtom __far *src, RAtom __far *dst,
@@ -1262,6 +1307,7 @@ static void CreateHydrogenBond( RAtom __far *srcCA, RAtom __far *dstCA,
     ptr->dstCA = dstCA;
     ptr->energy = energy;
     ptr->col = 0;
+
     ptr->altl = '\0';
     if (src && src->altl != '\0' && src->altl != ' ') ptr->altl = src->altl;
     if (dst && dst->altl != '\0' && dst->altl != ' ') ptr->altl = dst->altl;
@@ -1418,6 +1464,177 @@ void CreateNewBond (Long src, Long dst )
     CreateBond( src, dst, NormBondFlag );
 }
 
+/* PreTestSurface
+      sptr -- pointer to source atom
+	  dptr -- pointer to destination atom
+	  C    -- an array to receive the center of the
+	          intersection circle of the probe-radius
+		      extended atoms
+	  crad -- pointer to the radius of the intersection
+	          circle of the probe-radius extended
+			  atoms
+	  Un   -- an array of the normalized axis from
+	          sptr to dptr, scaled by 4096 (2**12)
+	  
+	  returns -- 
+	          -1 if the atoms are too far apart for
+			     the probe to touch
+			   0 if the atoms can be touched by the
+			     probe, but do not overlap
+			   1 if the atoms overlap (centers
+				 within the average of the radii)
+ */
+
+
+static int PreTestSurface(  RAtom __far *sptr,  RAtom __far *dptr, 
+      Long C[3],  int *crad, Long Un[3] )
+{
+    register Long dx, dy, dz;
+    register Long maxS, maxT, dist;
+    register int srad,drad;
+	Long lx, ly, lz, lxyzsq, sxyz, u1, rat, wpsq;
+
+    if ( !(sptr->model == dptr->model) ) return -1;
+    if ( !(sptr->altl == ' ' || sptr->altl == '\0') &&
+         !(dptr->altl == ' ' || dptr->altl == '\0') &&
+         !(sptr->altl == dptr->altl) ) return -1;
+    srad = sptr->radius;
+    drad = dptr->radius;
+    if (srad < 10 ) srad = Element[sptr->elemno].vdwrad;
+    if (drad < 10 ) drad = Element[dptr->elemno].vdwrad;
+    
+    /* Sum of van der Waals radii */
+	dist = srad + drad;
+	maxT = dist*dist/4;
+    dist += ProbeRadius+ProbeRadius;
+    maxS = dist*dist;  
+    
+    dx = sptr->xorg-dptr->xorg 
+         + sptr->fxorg-dptr->fxorg;   if( (dist=dx*dx)>=maxS ) return -1;
+    dy = sptr->yorg-dptr->yorg
+         + sptr->fyorg-dptr->fyorg;   if( (dist+=dy*dy)>=maxS ) return -1;
+    dz = sptr->zorg-dptr->zorg
+         + sptr->fzorg-dptr->fzorg;   if( (dist+=dz*dz)>=maxS ) return -1;
+
+	lx = sptr->xorg+sptr->fxorg-dptr->xorg-dptr->fxorg;
+    ly = sptr->yorg+sptr->fyorg-dptr->yorg-dptr->fyorg;
+    lz = sptr->zorg+sptr->fzorg-dptr->zorg-dptr->fzorg;
+    lxyzsq = lx*lx + ly*ly + lz*lz;
+    sxyz = (Long)(sqrt((double)lxyzsq)+.5);
+    u1 = (sxyz+
+      (((((srad+drad+(ProbeRadius+ProbeRadius))*
+      (srad-drad)))/sxyz))+1)>>1;
+	rat = (4096*u1)/sxyz;
+	C[0] = (rat*(sptr->xorg+sptr->fxorg)+(4096-rat)*(dptr->xorg+dptr->fxorg))/4096;
+	C[1] = (rat*(sptr->yorg+sptr->fyorg)+(4096-rat)*(dptr->yorg+dptr->fyorg))/4096;
+	C[2] = (rat*(sptr->zorg+sptr->fzorg)+(4096-rat)*(dptr->zorg+dptr->fzorg))/4096;
+    wpsq = ((((srad+ProbeRadius))*((srad+ProbeRadius))))
+      -u1*u1;
+    if (wpsq < 0 ) wpsq = 0;
+    *crad = (Long)rint(sqrt((double)wpsq));
+	Un[0] = -(lx*4096)/sxyz;
+	Un[1] = -(ly*4096)/sxyz;
+	Un[2] = -(lz*4096)/sxyz;
+
+	if (dist > maxT ) return 0;
+	return 1;	
+
+}
+
+
+static void TestSurface(  RAtom __far *sptr,  RAtom __far *dptr )
+{
+    register SurfBond __far *sbptr;
+    register Long dx, dy, dz;
+    register Long maxS, dist;
+    register int srad,drad;
+
+    if ( !(sptr->model == dptr->model) ) return;
+    if ( !(sptr->altl == ' ' || sptr->altl == '\0') &&
+         !(dptr->altl == ' ' || dptr->altl == '\0') &&
+         !(sptr->altl == dptr->altl) ) return;
+    srad = sptr->radius;
+    drad = dptr->radius;
+    if (srad < 10 ) srad = Element[sptr->elemno].vdwrad;
+    if (drad < 10 ) drad = Element[dptr->elemno].vdwrad;
+    
+    /* Sum of van der Walls radii */
+    dist = srad + drad + ProbeRadius+ProbeRadius;
+    maxS = dist*dist;  
+    
+    dx = sptr->xorg-dptr->xorg 
+         + sptr->fxorg-dptr->fxorg;   if( (dist=dx*dx)>=maxS ) return;
+    dy = sptr->yorg-dptr->yorg
+         + sptr->fyorg-dptr->fyorg;   if( (dist+=dy*dy)>=maxS ) return;
+    dz = sptr->zorg-dptr->zorg
+         + sptr->fzorg-dptr->fzorg;   if( (dist+=dz*dz)>=maxS ) return;
+
+    if( dist > (srad+drad-ProbeRadius)*(srad+drad-ProbeRadius) )
+    {   /* Reset Non-bonded flags! */
+        sptr->flag &= ~NonBondFlag;
+        dptr->flag &= ~NonBondFlag;
+
+        sbptr = ProcessSurfBond(sptr,dptr);
+        sbptr->sbnext = CurMolecule->sblist;
+        CurMolecule->sblist = sbptr;
+        Info.srfbondcount++;
+    }
+}
+
+/*
+    TestBuriedSurface
+	    aprt -- pointer to one atom of the pair being checked
+		dprt -- pointer to the other atom of the par being checked
+		eptr -- an atom that might bury the surface bond
+		C    -- the center of the circle at the neck of the surface bond
+		crad -- the radius of the orbit of the probe center around C
+		Un   -- the unit normal *4096 of the axis of the surface bond
+ */
+
+static int TestBuriedSurface( RAtom __far *aptr, RAtom __far *dptr, RAtom __far *eptr, 
+                              Long C[3], int crad, Long Un[3]) { 
+
+ 
+	register Long dx, dy, dz;
+    register Long maxS, dist, dec, decun;
+    register int erad;
+	Long ECxUn[3];
+
+    if ( eptr->model != aptr->model ) return -1; /* different models cannot bury each other */
+    if ( ( eptr->altl != ' ' && aptr->altl != ' ' && eptr->altl != aptr->altl) ||
+	     ( eptr->altl != ' ' && dptr->altl != ' ' && eptr->altl != dptr->altl) ) return -1;
+    erad = eptr->radius;
+    if (erad < 10 ) erad = Element[eptr->elemno].vdwrad;
+    
+    /* Sum of van der Walls radii */
+    dist = erad + crad + ProbeRadius;
+    maxS = dist*dist;  
+    
+    dx = eptr->xorg-C[0] 
+         + eptr->fxorg;   if( (dist=dx*dx)>=maxS ) return -1;
+    dy = eptr->yorg-C[1]
+         + eptr->fyorg;   if( (dist+=dy*dy)>=maxS ) return -1;
+    dz = eptr->zorg-C[2]
+         + eptr->fzorg;   if( (dist+=dz*dz)>=maxS ) return -1;
+
+    /* Compute the cross product of (E-C)XUn  */
+    ECxUn[0] = dy*Un[2]-dz*Un[1];
+	ECxUn[1] = dz*Un[0]-dx*Un[2];
+	ECxUn[2] = dx*Un[1]-dy*Un[0];
+	
+	/* Compute the hypotenuse */
+	
+	dec = (Long)(rint(4096*sqrt((double)dist)));
+	decun = (Long)(rint(sqrt((double)(ECxUn[0]*ECxUn[0] + ECxUn[1]*ECxUn[1] + ECxUn[2]*ECxUn[2]))));
+	dist += crad*crad + (2*crad*decun)/dec;
+	/* fprintf(stderr,"TBS E-C = {%ld,%ld,%ld} C={%ld,%ld,%ld}, re=%d, wp=%d, c=%ld,a=%ld,h=%d\n",
+	      dx, dy, dz, C[0],C[1],C[2],erad+ProbeRadius, crad, dec/4096,crad*decun/dec,
+		  (int)sqrt((double)dist)); */
+	if (dist < (erad+ProbeRadius)*(erad+ProbeRadius)) return 0;
+    
+    return 1;
+} 
+
 
 static void TestBonded(  RAtom __far *sptr,  RAtom __far *dptr, int flag )
 {
@@ -1437,8 +1654,8 @@ static void TestBonded(  RAtom __far *sptr,  RAtom __far *dptr, int flag )
     } else 
     {    /* Fast Bio-Macromolecule Bonding Calculation */
          if( (sptr->flag|dptr->flag) & HydrogenFlag )
-         {      max = MaxHBondDist;
-         } else max = MaxBondDist;
+         {      max = MaxHBondDsq;
+         } else max = MaxBondDsq;
     }
     
     dx = sptr->xorg-dptr->xorg 
@@ -1448,7 +1665,7 @@ static void TestBonded(  RAtom __far *sptr,  RAtom __far *dptr, int flag )
     dz = sptr->zorg-dptr->zorg
          + sptr->fzorg-dptr->fzorg;   if( (dist+=dz*dz)>max ) return;
 
-    if( dist > MinBondDist )
+    if( dist > MinBondDsq )
     {   /* Reset Non-bonded flags! */
         sptr->flag &= ~NonBondFlag;
         dptr->flag &= ~NonBondFlag;
@@ -1473,11 +1690,29 @@ static void ReclaimHBonds( HBond __far *ptr )
         FreeHBond = ptr;
     }
 }
-
-
-static void ReclaimBonds( Bond __far *ptr )
+static void ReclaimSurfBonds( Molecule __far *Mol)
 {
+    register SurfBond __far *ptr;
+    register SurfBond __far *temp;
+
+    ptr = Mol->sblist;
+
+    if( ptr )
+    {   temp = ptr;
+        while( temp->sbnext )
+            temp=temp->sbnext;
+        temp->sbnext = FreeSurfBond;
+        FreeSurfBond = ptr;
+    }
+    Mol->sblist = (SurfBond __far*)0;
+}
+
+
+static void ReclaimBonds( Molecule __far *Mol)
+{
+    register Bond __far *ptr;
     register Bond __far *temp;
+    ptr = Mol->blist;
 
     if( ptr )
     {   temp = ptr;
@@ -1486,6 +1721,23 @@ static void ReclaimBonds( Bond __far *ptr )
         temp->bnext = FreeBond;
         FreeBond = ptr;
     }
+    Mol->blist = (Bond __far*)0;
+}
+
+static void ReclaimChainBonds( Chain __far *Chn)
+{
+    register Bond __far *ptr;
+    register Bond __far *temp;
+    ptr = Chn->blist;
+
+    if( ptr )
+    {   temp = ptr;
+        while( temp->bnext )
+            temp=temp->bnext;
+        temp->bnext = FreeBond;
+        FreeBond = ptr;
+    }
+    Chn->blist = (Bond __far*)0;
 }
 
 
@@ -1521,10 +1773,10 @@ static Bond __far *ExtractBonds( Bond __far *ptr )
                + src->fzorg-dst->fzorg; dist += dz*dz;
         }
 
-        if( (temp->flag & NormBondFlag) &&  !(dist > max) )
+        if( ((temp->flag & NormBondFlag) &&  !(dist > max)))
         {   temp->bnext = FreeBond;
             FreeBond = temp;
-        } else /* Long or Double or Triple! */
+        } else /* Long or Double or Triple or Aromatic */
         {   temp->bnext = result;
             result = temp;
         }
@@ -1584,8 +1836,12 @@ void CreateMoleculeBonds( int info, int flag, int force )
 
     /* Save Explicit Long, Double and Triple Bonds on File Load */
     list = (Bond __far*)0;
-    if (!force)
+    if (!force) {
       list = ExtractBonds( CurMolecule->blist );
+    }
+     /* else {
+      ReclaimBonds (CurMolecule);
+    } */
     CurMolecule->blist = (Bond __far*)0;
     Info.bondcount = 0;
 
@@ -1655,6 +1911,185 @@ void CreateMoleculeBonds( int info, int flag, int force )
 }
 
 
+void CreateSurfaceBonds( void )
+{
+    register int i, x, y, z, im, xm, ym, zm;
+    register Long tx, ty, tz;
+    register Long txm, tym, tzm;
+    register Long mx, my, mz; 
+    register Long mxm, mym, mzm; 
+    register Long dx, dy, dz;
+    register int lx, ly, lz, ux, uy, uz;
+    register int lxm, lym, lzm, uxm, uym, uzm;
+    register RAtom __far *aptr, __far *dptr, __far *eptr;
+    register Chain __far *chain;
+    register Group __far *group;
+    register Long voxorder, voxorder2;
+	register SurfBond __far *sbptr;
+	Long C[3], Un[3];
+	int crad;
+	
+    if( !Database ) 
+        return;
+	
+    dx = (MaxX-MinX)+1;
+    dy = (MaxY-MinY)+1;
+    dz = (MaxZ-MinZ)+1;
+	
+    ReclaimSurfBonds( CurMolecule );
+    CurMolecule->sblist = (SurfBond __far*)0;
+    Info.srfbondcount = 0;
+	
+    ResetVoxelData();
+	
+    voxorder = VOXORDER;
+    voxorder2 =VOXORDER2;
+	
+    if ( dx+749 < 750*VOXORDER && 
+         dy+749 < 750*VOXORDER && 
+         dz+749 < 750*VOXORDER ) {
+		voxorder = (dx+749)/750;
+		if (dy > dx && dy > dz) voxorder = (dy+749)/750;
+		if (dz > dx && dz > dy) voxorder = (dz+749)/750;
+		voxorder2 = voxorder*voxorder;
+    } 
+	
+    /* Load the hash table with all selected atoms and
+		clear SurfBondFlag */
+	
+    for( chain=Database->clist; chain; chain=chain->cnext ) {
+        for( group=chain->glist; group; group=group->gnext ) {
+            for( aptr=group->alist; aptr; aptr=aptr->anext ) {
+				if (aptr->flag&SelectFlag) {  
+					
+					mx = aptr->xorg + aptr->fxorg - MinX;
+					my = aptr->yorg + aptr->fyorg - MinY;
+					mz = aptr->zorg + aptr->fzorg - MinZ;
+					
+					x = (int)((voxorder*mx)/dx);
+					y = (int)((voxorder*my)/dy);
+					z = (int)((voxorder*mz)/dz);
+					
+					i = voxorder2*x + voxorder*y + z;
+					aptr->next = (RAtom __far*)HashTable[i];
+					aptr->flag &= ~SurfBondFlag;
+					HashTable[i] = (void __far*)aptr;
+				}
+				VoxelsClean = False;
+			}
+		}
+	}
+	
+    /* Now run through the atoms again and check each atom
+		against the others using the hash table */
+	
+    for( chain=Database->clist; chain; chain=chain->cnext ) {
+        for( group=chain->glist; group; group=group->gnext ) {
+            for( aptr=group->alist; aptr; aptr=aptr->anext ) {
+				if (aptr->flag&SelectFlag && (!(aptr->flag&ExpandFlag))) {
+					
+					/* Look for atoms within 6 Angstroms plus 2
+					probe radii of atom aptr */
+					
+					mx = aptr->xorg + aptr->fxorg - MinX;
+					my = aptr->yorg + aptr->fyorg - MinY;
+					mz = aptr->zorg + aptr->fzorg - MinZ;
+					
+					tx = mx-AbsMaxAtomDiam-ProbeRadius-ProbeRadius;  
+					ty = my-AbsMaxAtomDiam-ProbeRadius-ProbeRadius;  
+					tz = mz-AbsMaxAtomDiam-ProbeRadius-ProbeRadius;  
+					
+					lx = (tx>0)? (int)((voxorder*tx)/dx) : 0;
+					ly = (ty>0)? (int)((voxorder*ty)/dy) : 0;
+					lz = (tz>0)? (int)((voxorder*tz)/dz) : 0;
+					
+					tx = mx+AbsMaxAtomDiam+ProbeRadius+ProbeRadius;  
+					ty = my+AbsMaxAtomDiam+ProbeRadius+ProbeRadius;  
+					tz = mz+AbsMaxAtomDiam+ProbeRadius+ProbeRadius;
+					
+					ux = (tx<dx)? (int)((voxorder*tx)/dx) : voxorder-1;
+					uy = (ty<dy)? (int)((voxorder*ty)/dy) : voxorder-1;
+					uz = (tz<dz)? (int)((voxorder*tz)/dz) : voxorder-1;
+					
+					for( x = lx; x <= ux; x++ ) { 
+						i = voxorder2*x + voxorder*ly;
+						for( y = ly; y<=uy; y++ ) {   
+							for( z = lz; z<=uz; z++ ) {
+							    register int abort; 
+								dptr = (RAtom __far*)HashTable[i+z];
+								while( dptr ) {
+								  if( dptr->serno <  aptr->serno ) { 
+									
+									abort = 0;
+									switch (PreTestSurface(aptr,dptr,C,&crad,Un)) {
+										
+										case 0: 
+											/* Look for atoms centers within ProbeRadius+AbsMaxAtomRad of C
+											i.e. 3 Angstroms plus the ProbeRadius of C */ 
+											mxm = C[0] - MinX; 
+											mym = C[1] - MinY; 
+											mzm = C[2] - MinZ;
+											
+											txm = mx-AbsMaxAtomRad-ProbeRadius;  
+											tym = my-AbsMaxAtomRad-ProbeRadius;  
+											tzm = mz-AbsMaxAtomRad-ProbeRadius;  
+											
+											lxm = (txm>0)? (int)((voxorder*txm)/dx) : 0;
+											lym = (tym>0)? (int)((voxorder*tym)/dy) : 0;
+											lzm = (tzm>0)? (int)((voxorder*tzm)/dz) : 0;
+											
+											txm = mxm+AbsMaxAtomRad+ProbeRadius; 
+											tym = mym+AbsMaxAtomRad+ProbeRadius;  
+											tzm = mzm+AbsMaxAtomRad+ProbeRadius;
+											
+											uxm = (txm<dx)? (int)((voxorder*txm)/dx) : voxorder-1;
+											uym = (tym<dy)? (int)((voxorder*tym)/dy) : voxorder-1;
+											uzm = (tzm<dz)? (int)((voxorder*tzm)/dz) : voxorder-1;
+											
+											for ( xm = lxm; (xm < uxm&& !abort) ; xm++ ) { 
+												im = voxorder2*xm + voxorder*lym;
+												for ( ym = lym; (ym<=uym && !abort) ; ym++ ) {   
+													for( zm = lz; (zm<=uzm && !abort); zm++ ) {
+														eptr = (RAtom __far*)HashTable[im+zm];
+														while( eptr && (eptr != dptr)  && (eptr != aptr) && !abort ) {
+															if (!TestBuriedSurface(aptr,dptr,eptr,C,crad,Un)) {  
+																abort = 1;
+																break;
+															}
+															eptr = eptr->next;
+														}
+													}
+													im += voxorder;
+												}
+											}
+												
+											break;
+										case 1:  abort = 0;
+											break;
+										case -1: abort = -1;
+											break;
+									}
+									if ( !abort ) {
+										sbptr = ProcessSurfBond(aptr,dptr);
+										sbptr->sbnext = CurMolecule->sblist;
+										CurMolecule->sblist = sbptr;
+										Info.srfbondcount++;
+									}
+								  }
+								  dptr = dptr->next;
+                                }
+                            }
+                            i += voxorder;
+                        }
+					}
+                }
+            }
+        }
+    }
+
+}
+
+
 
 /*=================================*/
 /*  Disulphide bridging functions  */
@@ -1737,6 +2172,7 @@ void FindDisulphideBridges( void )
 
     if( !Database ) return;
     ReclaimHBonds( CurMolecule->slist );
+    CurMolecule->slist = (HBond __far*)0;
     Info.ssbondcount = 0;
 
     for(chn1=Database->clist;chn1;chn1=chn1->cnext)
@@ -2205,8 +2641,7 @@ static void TestLadder( Chain __far *chain )
         hnextj = hnextj->hnext;
 
     while( chain )
-    {   if( nextj ) 
-            {
+    {   if( nextj ) {
             if( IsProtein(chain->glist->refno) )
             {   count = 1;
                 do {
@@ -2242,10 +2677,12 @@ static void TestLadder( Chain __far *chain )
 	            nextj = nextj->gnext;
 		} while( nextj );
 
-	    } else if( IsNucleo(chain->glist->refno) )
-		while( hnextj && !IsAminoBackbone(hnextj->src->refno) )
+	    } else if( IsNucleo(chain->glist->refno) ) {
+		while( hnextj && !IsAminoBackbone(hnextj->src->refno) ) {
 		    hnextj = hnextj->hnext;
             }
+            }
+        }
         chain = chain->cnext;
 	if( chain )
 	    nextj = chain->glist;
@@ -2603,10 +3040,11 @@ void DestroyDatabase( void )
     if( Database )
     {   ReclaimHBonds( Database->slist );
 	ReclaimHBonds( Database->hlist );
-	ReclaimBonds( Database->blist );
+	ReclaimBonds( Database );
+	ReclaimSurfBonds( Database );
 
 	while( Database->clist )
-	{   ReclaimBonds(Database->clist->blist);
+	{   ReclaimChainBonds(Database->clist);
 	    gptr = Database->clist->glist;
 	    if( gptr )
 	    {   ReclaimAtoms(gptr->alist);
@@ -2673,6 +3111,7 @@ void PurgeDatabase( void )
 void InitialiseDatabase( void )
 {
     FreeMolecule = (void __far*)0;
+    FreeSurfBond = (void __far*)0;
     FreeHBond = (void __far*)0;
     FreeChain = (void __far*)0;
     FreeGroup = (void __far*)0;
