@@ -1,9 +1,10 @@
+
 /***************************************************************************
- *                            RasMol 2.7.2.1.1                             *
+ *                               RasMol 2.7.3                              *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                            26 January 2004                              *
+ *                             6 February 2005                             *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -25,12 +26,19 @@
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
+ *                   RasMol 2.7.3   Feb 05                                 *
+ *                                                                         *
+ *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
+ *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
+ *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
+ *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
+ *of Energy.                                                               *
  *                                                                         *
  *                    and Incorporating Translations by                    *
  *  Author                               Item                      Language*
- *  Isabel Servn Martnez,                                                *
- *  Jos Miguel Fernndez Fernndez      2.6   Manual              Spanish *
- *  Jos Miguel Fernndez Fernndez      2.7.1 Manual              Spanish *
+ *  Isabel Servan Martinez,                                                *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
  *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
  *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
@@ -39,35 +47,12 @@
  *                             This Release by                             *
  * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2001               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2005               *
  *                                                                         *
- * Please read the file NOTICE for important notices which apply to this   *
- * package. If you are not going to make changes to RasMol, you are not    *
- * only permitted to freely make copies and distribute them, you are       *
- * encouraged to do so, provided you do the following:                     *
- *   * 1. Either include the complete documentation, especially the file   *
- *     NOTICE, with what you distribute or provide a clear indication      *
- *     where people can get a copy of the documentation; and               *
- *   * 2. Please give credit where credit is due citing the version and    *
- *     original authors properly; and                                      *
- *   * 3. Please do not give anyone the impression that the original       *
- *     authors are providing a warranty of any kind.                       *
- *                                                                         *
- * If you would like to use major pieces of RasMol in some other program,  *
- * make modifications to RasMol, or in some other way make what a lawyer   *
- * would call a "derived work", you are not only permitted to do so, you   *
- * are encouraged to do so. In addition to the things we discussed above,  *
- * please do the following:                                                *
- *   * 4. Please explain in your documentation how what you did differs    *
- *     from this version of RasMol; and                                    *
- *   * 5. Please make your modified source code available.                 *
- *                                                                         *
- * This version of RasMol is not in the public domain, but it is given     *
- * freely to the community in the hopes of advancing science. If you make  *
- * changes, please make them in a responsible manner, and please offer us  *
- * the opportunity to include those changes in future versions of RasMol.  *
+ *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
+ *Please read the file NOTICE for important notices which apply to this    *
+ *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
-
 /* molecule.h
  $Log: molecule.h,v $
  Revision 1.1  2004/05/07 19:46:16  yaya
@@ -155,13 +140,17 @@
 #define WideKnotFlag    0x0e
 
 /* Atom Flags */
-#define SphereFlag      0x02     /* Sphere representation */
-#define HeteroFlag      0x04     /* HETATM record         */
-#define HydrogenFlag    0x08     /* Hydrogen atom         */
+#define SphereFlag      0x02     /* Sphere representation         */
+#define HeteroFlag      0x04     /* HETATM record                 */
+#define HydrogenFlag    0x08     /* Hydrogen atom                 */
 #define NormAtomFlag    0x10
 #define NonBondFlag     0x20
-#define BreakFlag       0x40     /* Break in backbone     */
-#define StarFlag        0x80     /* Star representation   */
+#define BreakFlag       0x40     /* Break in backbone              */
+#define StarFlag        0x80     /* Star representation            */
+#define TouchFlag       0x100    /* Touch by probe                 */
+#define ExpandFlag      0x200    /* Expand by probe radius         */
+#define SurfBondFlag    0x400    /* Atom is part of a surface bond */
+
 
 /* Bond Flags */
 #define WireFlag        0x02     /* Depth-cued wireframe         */
@@ -215,7 +204,7 @@ typedef struct _Atom {
         void   *label;                    /* Atom Label Structure  */
         Byte   elemno;                    /* Atomic Number         */
         int    refno;                     /* ElemDesc index number */
-        Byte   flag;                      /* Database flags        */
+        short  flag;                      /* Database flags        */
         char   altl;                      /* Alternate Location    */
         short  irad;                      /* Image Radius          */
         short  mbox;                      /* Shadow Casting NOnce  */
@@ -223,6 +212,7 @@ typedef struct _Atom {
         short  visited;                   /* For bond rotation     */
         short  nbonds;                    /* For bond rotation     */ 
         struct _Atom __far *bonds[MaxBonds];
+        void   *surfbonds;                /* Surface bonds list    */
     } RAtom;
 
 
@@ -235,10 +225,25 @@ typedef struct _Bond {
         short aradius;                   /* World Alt Radius      */
         short iarad;                     /* Image Alt Radius      */
         short col;                       /* Bond Colour           */
-        Byte  flag;                      /* Database flags        */
+        short flag;                      /* Database flags        */
         char  altl;                      /* Bond Alternate Loc    */
     } Bond;
 
+typedef struct _SurfBond {
+        struct _SurfBond __far *sbnext;   /* Linked list of bonds  */
+        RAtom  __far *srcatom;            /* Source Atom Ptr       */
+        RAtom  __far *dstatom;            /* Destination Atom Ptr  */
+        Long   sxyz;                      /* Bond length           */
+        Long   wp;                        /* Torus waist           */
+        Long   w1,w2;                     /* Torus throats         */
+        Long   u1,u2;                     /* Probe offsets         */
+        Long   t1,t2;                     /* Torus offsets         */
+        short  col;                       /* Bond Colour           */
+        short  flag;                      /* Database flags        */
+        char   altl;                      /* Bond Alternate Loc    */
+    } SurfBond;
+
+
 typedef struct _Group {
         struct _Group __far *gnext;       /* Linked list of groups */
         RAtom __far *alist;                /* Linked list of atoms  */
@@ -251,7 +256,7 @@ typedef struct _Group {
         char  sinsert;                    /* Secondary insert code */
         Byte  refno;                      /* Residue index number  */
         Byte  struc;                      /* Secondary Structure   */
-        Byte  flag;                       /* Database flags        */
+        short flag;                       /* Database flags        */
         short model;                      /* Group Model Number    */
     } Group;
  
@@ -286,7 +291,7 @@ typedef struct _HBond {
         short aradius;                    /* World Alt Radius      */
         short iarad;                      /* Image Alt Radius      */
         Char offset;                      /* Signed Offset            */
-        Byte flag;                        /* Database flags           */
+        short flag;                       /* Database flags           */
         Byte col;                         /* Hydrogen bond colour     */
         char altl;                        /* Bond Alternate Loc       */
     } HBond;
@@ -296,6 +301,7 @@ typedef struct _Molecule {
         HBond __far *hlist;               /* Linked list of hbonds    */
         Chain __far *clist;               /* Linked list of chains    */
         Bond __far *blist;                /* Linked list of bonds     */
+        SurfBond __far *sblist;           /* Linked list of surf bonds*/
     } Molecule;
 
 
@@ -345,6 +351,7 @@ typedef struct _InfoStruct {
         double cell[6];
 
         Long bondcount;
+        Long srfbondcount;
         int chaincount;
         int ssbondcount;
         int hbondcount;
@@ -483,6 +490,7 @@ int MarkAtoms;
 
 int HBondChainsFlag;
 
+SurfBond __far *FreeSurfBond;
 HBond __far *FreeHBond;
 Bond __far *FreeBond;
 Bond __far *NewBond;
@@ -529,6 +537,7 @@ extern int MarkAtoms;
 
 extern int HBondChainsFlag;
 
+extern SurfBond __far *FreeSurfBond;
 extern HBond __far *FreeHBond;
 extern Bond __far *FreeBond;
 extern Bond __far *NewBond;
@@ -558,6 +567,7 @@ void CreateBond( Long, Long, int );
 void CreateBondOrder( Long, Long );
 void CreateNewBond( Long, Long );
 void CreateMoleculeBonds( int, int, int );
+void CreateSurfaceBonds( void );
 RAtom __far *FindCysSulphur( Group __far *group );
 void FindDisulphideBridges( void );
 void TestDisulphideBridge( Group __far *, Group __far *, RAtom __far * );
