@@ -1,9 +1,10 @@
+
 /***************************************************************************
- *                            RasMol 2.7.2.1.1                             *
+ *                               RasMol 2.7.3                              *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                            26 January 2004                              *
+ *                             6 February 2005                             *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -25,12 +26,19 @@
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
+ *                   RasMol 2.7.3   Feb 05                                 *
+ *                                                                         *
+ *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
+ *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
+ *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
+ *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
+ *of Energy.                                                               *
  *                                                                         *
  *                    and Incorporating Translations by                    *
  *  Author                               Item                      Language*
- *  Isabel Servn Martnez,                                                *
- *  Jos Miguel Fernndez Fernndez      2.6   Manual              Spanish *
- *  Jos Miguel Fernndez Fernndez      2.7.1 Manual              Spanish *
+ *  Isabel Servan Martinez,                                                *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
  *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
  *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
@@ -39,35 +47,12 @@
  *                             This Release by                             *
  * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2001               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2005               *
  *                                                                         *
- * Please read the file NOTICE for important notices which apply to this   *
- * package. If you are not going to make changes to RasMol, you are not    * 
- * only permitted to freely make copies and distribute them, you are       * 
- * encouraged to do so, provided you do the following:                     *
- *   * 1. Either include the complete documentation, especially the file   *
- *     NOTICE, with what you distribute or provide a clear indication      *
- *     where people can get a copy of the documentation; and               *
- *   * 2. Please give credit where credit is due citing the version and    * 
- *     original authors properly; and                                      *  
- *   * 3. Please do not give anyone the impression that the original       *   
- *     authors are providing a warranty of any kind.                       *
- *                                                                         *
- * If you would like to use major pieces of RasMol in some other program,  *
- * make modifications to RasMol, or in some other way make what a lawyer   *
- * would call a "derived work", you are not only permitted to do so, you   *
- * are encouraged to do so. In addition to the things we discussed above,  *
- * please do the following:                                                *
- *   * 4. Please explain in your documentation how what you did differs    *
- *     from this version of RasMol; and                                    *
- *   * 5. Please make your modified source code available.                 *
- *                                                                         *
- * This version of RasMol is not in the public domain, but it is given     *
- * freely to the community in the hopes of advancing science. If you make  *
- * changes, please make them in a responsible manner, and please offer us  *
- * the opportunity to include those changes in future versions of RasMol.  *
+ *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
+ *Please read the file NOTICE for important notices which apply to this    *
+ *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
-
 /* multiple.c
  $Log: multiple.c,v $
  Revision 1.1  2004/05/07 19:46:16  yaya
@@ -218,123 +203,127 @@ struct {
 
    /* graphics.h */
     
-    { DialValue,          sizeof (DialValue),      0},
+    { DialValue,          sizeof (DialValue),      0 },
 
     /* molecule.h */
-    { &Info,              sizeof (Info),           0},
-    { &MainGroupCount,    sizeof (MainGroupCount), 0},
-    { &HetaGroupCount,    sizeof (HetaGroupCount), 0},
-    { &MainAtomCount,     sizeof (MainAtomCount),  0},
-    { &HetaAtomCount,     sizeof (HetaAtomCount),  0},
-    { &CisBondCutOff,     sizeof (CisBondCutOff),  0},
-    { &MinX,              sizeof (MinX),           0},
-    { &MinY,              sizeof (MinY),           0},
-    { &MinZ,              sizeof (MinZ),           0},
-    { &MaxX,              sizeof (MaxX),           0},
-    { &MaxY,              sizeof (MaxY),           0},
-    { &MaxZ,              sizeof (MaxZ),           0},
-    { &HMinMaxFlag,       sizeof (HMinMaxFlag),    0},
-    { &MMinMaxFlag,       sizeof (MMinMaxFlag),    0},
-    { &MinMainTemp,       sizeof (MinMainTemp),    0},
-    { &MaxMainTemp,       sizeof (MaxMainTemp),    0},
-    { &MinHetaTemp,       sizeof (MinHetaTemp),    0},
-    { &MaxHetaTemp,       sizeof (MaxHetaTemp),    0},
-    { &MinMainRes,        sizeof (MinMainRes),     0},
-    { &MaxMainRes,        sizeof (MaxMainRes),     0},
-    { &MinHetaRes,        sizeof (MinHetaRes),     0},
-    { &MaxHetaRes,        sizeof (MaxHetaRes),     0},
-    { &MinAltl,           sizeof (MinAltl),        0},
-    { &MaxAltl,           sizeof (MaxAltl),        0},
-    { &CurMolecule,       sizeof (CurMolecule),    0},
-    { &CurChain,          sizeof (CurChain),       0},
-    { &CurGroup,          sizeof (CurGroup),       0},
-    { &CurAtom,           sizeof (CurAtom),        0},
-    { &IntList,           sizeof (IntList),        0},
-    { &Database,          sizeof (Database),       0},
-    { UserMask,           sizeof (UserMask),       0},
-    { &MinHBondDist,      sizeof (MinHBondDist),   0},
-    { &MaxHBondDist,      sizeof (MaxHBondDist),   0},
-    { &MinBondDist,       sizeof (MinBondDist),    0},
-    { &MaxBondDist,       sizeof (MaxBondDist),    0},
-    { &ElemNo,            sizeof (ElemNo),         0},
-    { &ResNo,             sizeof (ResNo),          0},
-    { &HasHydrogen,       sizeof (HasHydrogen),    0},
-    { &MaskCount,         sizeof (MaskCount),      0},
-    { &NMRModel,          sizeof (NMRModel),       0},
-    { &NullBonds,         sizeof (NullBonds),      0},
-    { &MarkAtoms,         sizeof (MarkAtoms),      0},
-    { &HBondChainsFlag,   sizeof (HBondChainsFlag), 0},
+    { &Info,              sizeof (Info),           0 },
+    { &MainGroupCount,    sizeof (MainGroupCount), 0 },
+    { &HetaGroupCount,    sizeof (HetaGroupCount), 0 },
+    { &MainAtomCount,     sizeof (MainAtomCount),  0 },
+    { &HetaAtomCount,     sizeof (HetaAtomCount),  0 },
+    { &CisBondCutOff,     sizeof (CisBondCutOff),  0 },
+    { &MinX,              sizeof (MinX),           0 },
+    { &MinY,              sizeof (MinY),           0 },
+    { &MinZ,              sizeof (MinZ),           0 },
+    { &MaxX,              sizeof (MaxX),           0 },
+    { &MaxY,              sizeof (MaxY),           0 },
+    { &MaxZ,              sizeof (MaxZ),           0 },
+    { &HMinMaxFlag,       sizeof (HMinMaxFlag),    0 },
+    { &MMinMaxFlag,       sizeof (MMinMaxFlag),    0 },
+    { &MinMainTemp,       sizeof (MinMainTemp),    0 },
+    { &MaxMainTemp,       sizeof (MaxMainTemp),    0 },
+    { &MinHetaTemp,       sizeof (MinHetaTemp),    0 },
+    { &MaxHetaTemp,       sizeof (MaxHetaTemp),    0 },
+    { &MinMainRes,        sizeof (MinMainRes),     0 },
+    { &MaxMainRes,        sizeof (MaxMainRes),     0 },
+    { &MinHetaRes,        sizeof (MinHetaRes),     0 },
+    { &MaxHetaRes,        sizeof (MaxHetaRes),     0 },
+    { &MinAltl,           sizeof (MinAltl),        0 },
+    { &MaxAltl,           sizeof (MaxAltl),        0 },
+    { &CurMolecule,       sizeof (CurMolecule),    0 },
+    { &CurChain,          sizeof (CurChain),       0 },
+    { &CurGroup,          sizeof (CurGroup),       0 },
+    { &CurAtom,           sizeof (CurAtom),        0 },
+    { &IntList,           sizeof (IntList),        0 },
+    { &Database,          sizeof (Database),       0 },
+    { UserMask,           sizeof (UserMask),       0 },
+    { &MinHBondDist,      sizeof (MinHBondDist),   0 },
+    { &MaxHBondDist,      sizeof (MaxHBondDist),   0 },
+    { &MinBondDist,       sizeof (MinBondDist),    0 },
+    { &MaxBondDist,       sizeof (MaxBondDist),    0 },
+    { &ElemNo,            sizeof (ElemNo),         0 },
+    { &ResNo,             sizeof (ResNo),          0 },
+    { &HasHydrogen,       sizeof (HasHydrogen),    0 },
+    { &MaskCount,         sizeof (MaskCount),      0 },
+    { &NMRModel,          sizeof (NMRModel),       0 },
+    { &NullBonds,         sizeof (NullBonds),      0 },
+    { &MarkAtoms,         sizeof (MarkAtoms),      0 },
+    { &HBondChainsFlag,   sizeof (HBondChainsFlag), 0 },
 
     /* render.h */
-    { &VoxelsClean,       sizeof (VoxelsClean),    0},
+    { &VoxelsClean,       sizeof (VoxelsClean),    0 },
 
     /* repres.h */
-    { &DotPtr,            sizeof (DotPtr),         0},
+    { &DotPtr,            sizeof (DotPtr),         0 },
+    { &ProbeRadius,       sizeof (ProbeRadius),    0 },
+    { &iProbeRad,         sizeof (iProbeRad),      0 },
+
 
     /* command.h */
 
-    { &SelectCount,       sizeof (SelectCount),    0},
+    { &SelectCount,       sizeof (SelectCount),    0 },
      
     /* transfor.h */
-    { &LastRX,            sizeof (LastRX),         0},
-    { &LastRY,            sizeof (LastRY),         0},
-    { &LastRZ,            sizeof (LastRZ),         0},
-    { &LastTX,            sizeof (LastTX),         0},
-    { &LastTY,            sizeof (LastTY),         0},
-    { &LastTZ,            sizeof (LastTZ),         0},
-    { &CenX,              sizeof (CenX),           0},
-    { &CenY,              sizeof (CenY),           0},
-    { &CenZ,              sizeof (CenZ),           0},
-    { &ShiftS,            sizeof (ShiftS),         0},
-    { &XlateCen,          sizeof (XlateCen),       0},
-    { &OrigCX,            sizeof (OrigCX),         0},
-    { &OrigCY,            sizeof (OrigCY),         0},
-    { &OrigCZ,            sizeof (OrigCZ),         0},
-    { RotX,               sizeof (RotX),           0},
-    { RotY,               sizeof (RotY),           0},
-    { RotZ,               sizeof (RotZ),           0},
-    { LRotX,              sizeof (LRotX),          0},
-    { LRotY,              sizeof (LRotY),          0},
-    { LRotZ,              sizeof (LRotZ),          0},
-    { LOffset,            sizeof (LOffset),        0},
-    { MatX,               sizeof (MatX),           0},
-    { MatY,               sizeof (MatY),           0},
-    { MatZ,               sizeof (MatZ),           0},
-    { InvX,               sizeof (InvX),           0},
-    { InvY,               sizeof (InvY),           0},
-    { InvZ,               sizeof (InvZ),           0},
-    { &Zoom,              sizeof (Zoom),           0},
-    { &Scale,             sizeof (Scale),          0},
-    { &IScale,            sizeof (IScale),         0},
+    { &LastRX,            sizeof (LastRX),         0 },
+    { &LastRY,            sizeof (LastRY),         0 },
+    { &LastRZ,            sizeof (LastRZ),         0 },
+    { &LastTX,            sizeof (LastTX),         0 },
+    { &LastTY,            sizeof (LastTY),         0 },
+    { &LastTZ,            sizeof (LastTZ),         0 },
+    { &CenX,              sizeof (CenX),           0 },
+    { &CenY,              sizeof (CenY),           0 },
+    { &CenZ,              sizeof (CenZ),           0 },
+    { &ShiftS,            sizeof (ShiftS),         0 },
+    { &XlateCen,          sizeof (XlateCen),       0 },
+    { &OrigCX,            sizeof (OrigCX),         0 },
+    { &OrigCY,            sizeof (OrigCY),         0 },
+    { &OrigCZ,            sizeof (OrigCZ),         0 },
+    { RotX,               sizeof (RotX),           0 },
+    { RotY,               sizeof (RotY),           0 },
+    { RotZ,               sizeof (RotZ),           0 },
+    { LRotX,              sizeof (LRotX),          0 },
+    { LRotY,              sizeof (LRotY),          0 },
+    { LRotZ,              sizeof (LRotZ),          0 },
+    { LOffset,            sizeof (LOffset),        0 },
+    { MatX,               sizeof (MatX),           0 },
+    { MatY,               sizeof (MatY),           0 },
+    { MatZ,               sizeof (MatZ),           0 },
+    { InvX,               sizeof (InvX),           0 },
+    { InvY,               sizeof (InvY),           0 },
+    { InvZ,               sizeof (InvZ),           0 },
+    { &Zoom,              sizeof (Zoom),           0 },
+    { &Scale,             sizeof (Scale),          0 },
+    { &IScale,            sizeof (IScale),         0 },
      
-    { &XOffset,           sizeof (XOffset),        0},
-    { &YOffset,           sizeof (YOffset),        0},
-    { &ZOffset,           sizeof (ZOffset),        0},
+    { &XOffset,           sizeof (XOffset),        0 },
+    { &YOffset,           sizeof (YOffset),        0 },
+    { &ZOffset,           sizeof (ZOffset),        0 },
      
     /* transfor.h */
-    { &UseScreenClip,     sizeof (UseScreenClip),  0},
-    { &DrawAtoms,         sizeof (DrawAtoms),      0},
-    { &DrawBonds,         sizeof (DrawBonds),      0},
-    { &DrawRibbon,        sizeof (DrawRibbon),     0},
-    { &LocalRadius,       sizeof (LocalRadius),  0},
-    { &MaxAtomRadius,     sizeof (MaxAtomRadius),  0},
-    { &MaxBondRadius,     sizeof (MaxBondRadius),  0},
-    { &ZoneBoth,          sizeof (ZoneBoth),       0},
+    { &UseScreenClip,     sizeof (UseScreenClip),  0 },
+    { &DrawAtoms,         sizeof (DrawAtoms),      0 },
+    { &DrawSurf,          sizeof (DrawSurf),       0 },
+    { &DrawBonds,         sizeof (DrawBonds),      0 },
+    { &DrawRibbon,        sizeof (DrawRibbon),     0 },
+    { &LocalRadius,       sizeof (LocalRadius),    0 },
+    { &MaxAtomRadius,     sizeof (MaxAtomRadius),  0 },
+    { &MaxBondRadius,     sizeof (MaxBondRadius),  0 },
+    { &ZoneBoth,          sizeof (ZoneBoth),       0 },
 
     /* bond rotation stuff */
-    { &BRotValue, sizeof (BRotValue), 0},
-    { &BLastRot, sizeof (BLastRot), 0},
-    { BAxis, sizeof (BAxis), 0},
-    { &BSrcAtom, sizeof (BSrcAtom), 0},
-    { &BDstAtom, sizeof (BDstAtom), 0},
-    { &BondSelected, sizeof (BondSelected), 0},
-    { &BondsSelected, sizeof (BondsSelected), 0},
+    { &BRotValue, sizeof (BRotValue), 0 },
+    { &BLastRot, sizeof (BLastRot), 0 },
+    { BAxis, sizeof (BAxis), 0 },
+    { &BSrcAtom, sizeof (BSrcAtom), 0 },
+    { &BDstAtom, sizeof (BDstAtom), 0 },
+    { &BondSelected, sizeof (BondSelected), 0 },
+    { &BondsSelected, sizeof (BondsSelected), 0 },
      
 #ifdef MOVIE_DONE
     /* script.c movie stuff */
-    { NewDialValue   ,    sizeof (NewDialValue), 0},
-    { &firstCmd, sizeof (firstCmd), 0},
-    { LastDialValue  ,    sizeof (LastDialValue), 0},
+    { NewDialValue   ,    sizeof (NewDialValue), 0 },
+    { &firstCmd, sizeof (firstCmd), 0 },
+    { LastDialValue  ,    sizeof (LastDialValue), 0 },
 #endif
      
     { NULL, 0, 0}
