@@ -1,9 +1,10 @@
+
 /***************************************************************************
- *                            RasMol 2.7.2.1.1                             *
+ *                               RasMol 2.7.3                              *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                            26 January 2004                              *
+ *                             6 February 2005                             *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -25,12 +26,19 @@
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
+ *                   RasMol 2.7.3   Feb 05                                 *
+ *                                                                         *
+ *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
+ *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
+ *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
+ *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
+ *of Energy.                                                               *
  *                                                                         *
  *                    and Incorporating Translations by                    *
  *  Author                               Item                      Language*
- *  Isabel Servn Martnez,                                                *
- *  Jos Miguel Fernndez Fernndez      2.6   Manual              Spanish *
- *  Jos Miguel Fernndez Fernndez      2.7.1 Manual              Spanish *
+ *  Isabel Servan Martinez,                                                *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
  *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
  *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
@@ -39,35 +47,12 @@
  *                             This Release by                             *
  * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2001               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2005               *
  *                                                                         *
- * Please read the file NOTICE for important notices which apply to this   *
- * package. If you are not going to make changes to RasMol, you are not    *
- * only permitted to freely make copies and distribute them, you are       *
- * encouraged to do so, provided you do the following:                     *
- *   * 1. Either include the complete documentation, especially the file   *
- *     NOTICE, with what you distribute or provide a clear indication      *
- *     where people can get a copy of the documentation; and               *
- *   * 2. Please give credit where credit is due citing the version and    *
- *     original authors properly; and                                      *
- *   * 3. Please do not give anyone the impression that the original       *
- *     authors are providing a warranty of any kind.                       *
- *                                                                         *
- * If you would like to use major pieces of RasMol in some other program,  *
- * make modifications to RasMol, or in some other way make what a lawyer   *
- * would call a "derived work", you are not only permitted to do so, you   *
- * are encouraged to do so. In addition to the things we discussed above,  *
- * please do the following:                                                *
- *   * 4. Please explain in your documentation how what you did differs    *
- *     from this version of RasMol; and                                    *
- *   * 5. Please make your modified source code available.                 *
- *                                                                         *
- * This version of RasMol is not in the public domain, but it is given     *
- * freely to the community in the hopes of advancing science. If you make  *
- * changes, please make them in a responsible manner, and please offer us  *
- * the opportunity to include those changes in future versions of RasMol.  *
+ *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
+ *Please read the file NOTICE for important notices which apply to this    *
+ *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
-
 /* rasmac.c
  $Log: rasmac.c,v $
  Revision 1.1  2004/05/07 19:46:16  yaya
@@ -1377,6 +1362,17 @@ static void HandleMenu( long hand )
                                       DisableBackbone();
                                       ReDrawFlag |= RFRefresh;
                                       break;
+
+                            case(9):  /* Molecular Surface */
+                                      DrawSurf = True;
+                                      ProbeRadius = 350;
+                                      SetVanWaalRadius( SphereFlag | TouchFlag );
+                                      DisableWireframe();
+                                      SetRibbonStatus(False,0,0);
+                                      DisableBackbone();
+                                      CreateSurfaceBonds();
+                                      ReDrawFlag |= RFRefresh;
+                                      break;
                         }
                         break;              
                             
@@ -2041,6 +2037,7 @@ static void HandleMouseDownEvent( EventRecord *ptr )
     register long hand;
     register int code;
     WindowPtr win;
+    GrafPtr savePort;
     
     code = FindWindow(ptr->where,&win);
     switch( code )
@@ -2053,13 +2050,34 @@ static void HandleMouseDownEvent( EventRecord *ptr )
         case(inSysWindow):  SystemClick(ptr,win);
                             break;
 
-        case(inContent):    if( win == CanvWin )
-                            {   ClickCanvWin( ptr );
+        case(inContent):    // Need to recheck that ptr is in the window
+                            GetPort(&savePort);
+                            SetPort(CanvWin);
+                            GlobalToLocal(&ptr->where);
+                            if((win == CmndWin) || ( win == CanvWin && 
+                               ptr->where.h >=0 && ptr->where.h<=XRange &&
+                               ptr->where.v >=0 && ptr->where.v<=YRange)) {
+                              LocalToGlobal(&ptr->where);
+                              SetPort(savePort);
+                              if( win == CanvWin )
+                              {   ClickCanvWin( ptr );
+                              } else {
+                                if( win == CmndWin )
+                                {   ClickCmndWin( ptr );
+                                }
+                              }
+                              break;
                             } else {
-                              if( win == CmndWin )
-                              {   ClickCmndWin( ptr );
+                              if (win == CanvWin &&
+                                  ptr->where.h >=XRange && ptr->where.h<=XRange+24 &&
+                                  ptr->where.v >=YRange && ptr->where.v<=YRange+24) {
+                                  LocalToGlobal(&ptr->where);
+                                  SetPort(savePort);
+                                  GrowCanvWin( ptr->where );
+                                  break;
                               }
                             }
+                            SetPort(savePort);
                             break;
         
         case(inDrag):       if( (win==CanvWin) 
@@ -2454,6 +2472,7 @@ static void InitDefaultValues( void )
     ReDrawFlag = RFInitial;
     LabelOptFlag = False;
     CalcBondsFlag = True;
+    CalcSurfFlag = False;
     AllowWrite = False;
 }
 
