@@ -1,9 +1,10 @@
+
 /***************************************************************************
- *                            RasMol 2.7.2.1.1                             *
+ *                               RasMol 2.7.3                              *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                            26 January 2004                              *
+ *                             6 February 2005                             *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -25,12 +26,19 @@
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
+ *                   RasMol 2.7.3   Feb 05                                 *
+ *                                                                         *
+ *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
+ *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
+ *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
+ *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
+ *of Energy.                                                               *
  *                                                                         *
  *                    and Incorporating Translations by                    *
  *  Author                               Item                      Language*
- *  Isabel Servn Martnez,                                                *
- *  Jos Miguel Fernndez Fernndez      2.6   Manual              Spanish *
- *  Jos Miguel Fernndez Fernndez      2.7.1 Manual              Spanish *
+ *  Isabel Servan Martinez,                                                *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
  *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
  *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
@@ -39,35 +47,12 @@
  *                             This Release by                             *
  * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2001               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2005               *
  *                                                                         *
- * Please read the file NOTICE for important notices which apply to this   *
- * package. If you are not going to make changes to RasMol, you are not    * 
- * only permitted to freely make copies and distribute them, you are       * 
- * encouraged to do so, provided you do the following:                     *
- *   * 1. Either include the complete documentation, especially the file   *
- *     NOTICE, with what you distribute or provide a clear indication      *
- *     where people can get a copy of the documentation; and               *
- *   * 2. Please give credit where credit is due citing the version and    * 
- *     original authors properly; and                                      *  
- *   * 3. Please do not give anyone the impression that the original       *   
- *     authors are providing a warranty of any kind.                       *
- *                                                                         *
- * If you would like to use major pieces of RasMol in some other program,  *
- * make modifications to RasMol, or in some other way make what a lawyer   *
- * would call a "derived work", you are not only permitted to do so, you   *
- * are encouraged to do so. In addition to the things we discussed above,  *
- * please do the following:                                                *
- *   * 4. Please explain in your documentation how what you did differs    *
- *     from this version of RasMol; and                                    *
- *   * 5. Please make your modified source code available.                 *
- *                                                                         *
- * This version of RasMol is not in the public domain, but it is given     *
- * freely to the community in the hopes of advancing science. If you make  *
- * changes, please make them in a responsible manner, and please offer us  *
- * the opportunity to include those changes in future versions of RasMol.  *
+ *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
+ *Please read the file NOTICE for important notices which apply to this    *
+ *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
-
 /* render.c
  $Log: render.c,v $
  Revision 1.1  2004/05/07 19:46:16  yaya
@@ -155,25 +140,9 @@
 
 #define PoolSize       16
 #define ApproxZero     1.0E-3
-#define RootSix        2.44948974278
 #define INFINITY       200000
 #define FUDGEFACTOR    1000
 
-#ifdef INVERT
-#define InvertY(y) (y)
-#define ProperY(y) (-y)
-#else
-#define InvertY(y) (-(y))
-#define ProperY(y) (y)
-#endif
-
-
-/* These define light source position */
-#define LightDot(x,y,z)  ((x)+(y)+(z)+(z))
-#define LightLength      RootSix
-#define LightXComp       1
-#define LightYComp       1
-#define LightZComp       2
 
 
 /* Macros for commonly used loops */
@@ -181,6 +150,7 @@
                      for(group=chain->glist;group;group=group->gnext)    \
                      for(aptr=group->alist;aptr;aptr=aptr->anext)
 #define ForEachBond  for(bptr=Database->blist;bptr;bptr=bptr->bnext)
+#define ForEachSurfBond  for(sbptr=Database->sblist;sbptr;sbptr=sbptr->sbnext)
 #define ForEachBack  for(chain=Database->clist;chain;chain=chain->cnext) \
                      for(bptr=chain->blist;bptr;bptr=bptr->bnext)
 
@@ -446,15 +416,17 @@ void ReAllocBuffers( void )
     register int index;
     register long len, temp;
 
-    temp = (long)XRange*YRange*sizeof(short)+32;
 #ifdef MSWIN
+    temp = (long)XRange*YRange*sizeof(short)+32;
     if( DBufHandle ) GlobalFree(DBufHandle);
     DBufHandle = GlobalAlloc(GMEM_MOVEABLE,temp);
     if( !DBufHandle ) FatalRenderError("depth buffer");
 #else
+    temp = (long)XRange*YRange*sizeof(short)+32;
     if( DBuffer ) _ffree( DBuffer );
     DBuffer = (short*)_fmalloc( temp );
     if( !DBuffer ) FatalRenderError("depth buffer");
+    temp = (long)XRange*YRange*sizeof(int)+32;
 #endif
     DBClear=False;
 
@@ -542,10 +514,13 @@ static void PrepareYBucket( void )
     for( scan=0; scan<BuckY; scan++ )
 	*temp++ = (void __far*)0;
 
+    iProbeRad = (int)rint(Scale*ProbeRadius);
+
     if( UseClipping )
     {   ForEachAtom
-	    if( aptr->flag&SphereFlag )
+	    if( aptr->flag&(SphereFlag|TouchFlag) )
 	    {   rad = aptr->irad;
+                if (aptr->flag&ExpandFlag) rad += iProbeRad;
 		if( (aptr->x-rad>=XRange) || 
 		    (aptr->x+rad<0) || (aptr->y+rad<0) )
 		    continue;
@@ -561,8 +536,9 @@ static void PrepareYBucket( void )
 	    }
     } else
 	ForEachAtom
-	    if( aptr->flag&SphereFlag )
+	    if( aptr->flag&(SphereFlag|TouchFlag) )
 	    {   scan = aptr->y-aptr->irad;
+                if (aptr->flag&ExpandFlag) scan -= iProbeRad;
 		aptr->bucket = YBucket[scan];
 		YBucket[scan] = aptr;
 	    }
@@ -667,8 +643,9 @@ void CreateVoxelData( int flag )
 	if( flag != SphereFlag )
 	{   if( SolventDots || !ProbeRadius )
 	    {   rad = ElemVDWRadius(aptr->elemno);
-	    } else rad = ProbeRadius;
-	} else rad = aptr->radius;  
+	    } else rad = ElemVDWRadius(aptr->elemno)+ProbeRadius;
+	} else rad = aptr->radius +
+            (aptr->flag&ExpandFlag)?ProbeRadius:0;  
 	radius2 = (Long)rad*rad;
 
 	lvx = (int)((mx-rad)*IVoxRatio);  hvx = (int)((mx+rad)*IVoxRatio);
@@ -852,7 +829,6 @@ static void ScanLine( void )
     register short __huge *dbase;
     register short __huge *dptr;
     register Pixel __huge *fptr;
-    register Byte __far *tptr;
 
     register int pos,depth,inten;
     register int lastx,wide,scan;
@@ -875,17 +851,16 @@ static void ScanLine( void )
 	prev = &list;
 	for( ptr=list; ptr; ptr=ptr->next )
 	{   dy = scan - ptr->y;
-	    wide = LookUp[ptr->irad][AbsFun(dy)];
+	    wide = pythag(ptr->irad,AbsFun(dy));
 	    lastx = (XRange-1)-ptr->x;
 	    if( wide<lastx ) lastx=wide;
 	    dx = - MinFun(wide,ptr->x);
 
 	    iptr = IBuffer+ptr->x;
-	    tptr = LookUp[wide];
 
 	    dptr = dbase+ptr->x+dx;
 	    while( dx<=lastx )
-	    {   depth = tptr[AbsFun(dx)]+ptr->z;
+	    {   depth = pythag(wide,AbsFun(dx))+ptr->z;
 		UpdateScanAcross;
 	    }
 
@@ -937,70 +912,99 @@ static void DisplaySpaceFill( void )
     register Group __far *group;
     register RAtom __far *aptr;
 
+    iProbeRad = (int)rint(Scale*(Real)ProbeRadius);
     if( UseShadow )
     {   if( !BucketFlag )
 	    PrepareYBucket();
 	ScanLine();
     } else if( UseClipping )
     {   ForEachAtom
-	    if( aptr->flag&SphereFlag )
-		ClipSphere(aptr->x,aptr->y,aptr->z,aptr->irad,aptr->col);
+	    if( aptr->flag&(SphereFlag|TouchFlag) )
+		ClipSphere(aptr->x,aptr->y,aptr->z,
+                    aptr->irad+((aptr->flag&ExpandFlag)?iProbeRad:0),
+                    aptr->col);
     } else 
 	ForEachAtom
-	    if( aptr->flag&SphereFlag )
-		DrawSphere(aptr->x,aptr->y,aptr->z,aptr->irad,aptr->col);
+	    if( aptr->flag&(SphereFlag|TouchFlag) )
+		DrawSphere(aptr->x,aptr->y,aptr->z,
+                    aptr->irad+((aptr->flag&ExpandFlag)?iProbeRad:0),
+                    aptr->col);
 }
 
+
 static void DisplayStars( void )
 {
     register Chain __far *chain;
     register Group __far *group;
     register RAtom __far *aptr;
 
+    iProbeRad = (int)rint(Scale*ProbeRadius);
+
     if( UseClipping )
     {   ForEachAtom
 	    if( aptr->flag&StarFlag )
-		ClipStar(aptr->x,aptr->y,aptr->z,aptr->radius,aptr->col);
+		ClipStar(aptr->x,aptr->y,aptr->z,
+                  aptr->radius+(aptr->flag&ExpandFlag?ProbeRadius:0),
+                  aptr->col);
     } else 
 	ForEachAtom
 	    if( aptr->flag&StarFlag )
-		DrawStar(aptr->x,aptr->y,aptr->z,aptr->radius,aptr->col);
+		DrawStar(aptr->x,aptr->y,aptr->z,
+                  aptr->radius+(aptr->flag&ExpandFlag?ProbeRadius:0),
+                  aptr->col);
 }
 
 
 static void DisplayWireframe( void )
 {
     register Bond __far *bptr;
+    register SurfBond __far *sbptr;
     register RAtom __far *s;
     register RAtom __far *d;
-    register int sc,dc;
+    register int sc,dc,stmp;
+	
+    iProbeRad = (int)rint(Scale*(Real)ProbeRadius);
 
     if( UseClipping )
     {   ForEachBond
 	   if( bptr->flag & DrawBondFlag )
            {   s = bptr->srcatom; d = bptr->dstatom;
-	       if( !bptr->col ) 
-	       {   sc = s->col;  dc = d->col;
-	       } else sc = dc = bptr->col;
+
+
+
+	       if( !bptr->col ) {
+	         sc = s->col;  dc = d->col;
+	       } else {
+                 sc = dc = bptr->col;
+
+
+               }
 
 	       if( bptr->flag&WireFlag )
 	       {   ClipTwinVector(s->x,s->y,s->z,d->x,d->y,d->z,sc,dc,bptr->altl);
 	       } else if( bptr->flag&CylinderFlag )
 	       {   if( bptr->irad>0 )
 	           {  ClipCylinder(s->x,s->y,s->z,d->x,d->y,d->z,
-                                   sc,dc,bptr->irad, bptr->altl,bptr->iarad);
+                                   sc,dc,bptr->irad, bptr->altl, bptr->iarad);
 	           } else ClipTwinLine(s->x,s->y,s->z,d->x,d->y,d->z,
 				   sc+ColourMask,dc+ColourMask,bptr->altl);
                } else /* bptr->flag & DashFlag */
                    ClipDashVector(s->x,s->y,s->z,d->x,d->y,d->z,sc,dc,bptr->altl);
 	   }
-    } else
+    } else {
 	ForEachBond
 	   if( bptr->flag & DrawBondFlag )
            {   s = bptr->srcatom; d = bptr->dstatom;
+
+
+
                if( !bptr->col )
                {   sc = s->col;  dc = d->col;
-               } else sc = dc = bptr->col;
+               } else {
+                 sc = dc = bptr->col;
+
+
+               }
 
                if( bptr->flag&WireFlag )
                {      DrawTwinVector(s->x,s->y,s->z,d->x,d->y,d->z,sc,dc,
@@ -1014,6 +1018,74 @@ static void DisplayWireframe( void )
 	       } else ClipDashVector(s->x,s->y,s->z,d->x,d->y,d->z,sc,dc,
                         bptr->altl);
            }
+     } 
+     if (DrawSurf && DrawAtoms)
+     ForEachSurfBond
+     {   s = sbptr->srcatom; d = sbptr->dstatom;
+	     if (s->flag&SelectFlag && d->flag&SelectFlag
+	         && !(s->flag&ExpandFlag || d->flag&ExpandFlag )) {
+
+
+
+         if( !sbptr->col ) {
+           sc = s->col;  dc = d->col;
+         } else {
+           sc = dc = sbptr->col;
+
+
+         }
+         SBD.rad = s->irad;
+         if (d->irad > SBD.rad) SBD.rad = d->irad;
+         if (iProbeRad > SBD.rad) SBD.rad = iProbeRad;
+         SBD.x1 = s->x;
+         SBD.y1 = s->y;
+         SBD.z1 = s->z;
+         SBD.x2 = d->x;
+         SBD.y2 = d->y;
+         SBD.z2 = d->z;
+         SBD.U[0] = SBD.x2-SBD.x1;
+         SBD.U[1] = SBD.y2-SBD.y1;
+         SBD.U[2] = SBD.z2-SBD.z1;
+         SBD.sxyz = (LScale*sbptr->sxyz)>>4;
+         SBD.c1 = sc;
+         SBD.c2 = dc;
+         SBD.u1 = (LScale*sbptr->u1)>>4;
+         SBD.u2 = (LScale*sbptr->u2)>>4;
+         SBD.wp = (LScale*sbptr->wp)>>4;
+         SBD.t1 = (LScale*sbptr->t1)>>4;
+         SBD.t2 = (LScale*sbptr->t2)>>4;
+         SBD.w1 = (LScale*sbptr->w1)>>4;
+         SBD.w2 = (LScale*sbptr->w2)>>4;
+
+         SBD.s0=0;
+         SBD.s1=1;
+         SBD.s2=2;
+
+         if (AbsFun(SBD.U[0]) > AbsFun(SBD.U[1])) {
+             SBD.s0 = 1;
+             SBD.s1 = 0;
+         }
+         if (AbsFun(SBD.U[SBD.s1]) > AbsFun(SBD.U[2])) {
+             stmp = SBD.s1;
+             SBD.s1 = SBD.s2;
+             SBD.s2 = stmp;
+         }
+         if (AbsFun(SBD.U[SBD.s0]) > AbsFun(SBD.U[SBD.s1])) {
+             stmp = SBD.s0;
+             SBD.s0 = SBD.s1;
+             SBD.s1 = stmp;
+         }
+
+         SBD.Us0Us1 = SBD.U[SBD.s0]*SBD.U[SBD.s1];
+         SBD.Us0Us0_Us2Us2 = SBD.U[SBD.s0]*SBD.U[SBD.s0]+SBD.U[SBD.s2]*SBD.U[SBD.s2];
+         SBD.Us1Us1_Us2Us2 = SBD.U[SBD.s1]*SBD.U[SBD.s1]+SBD.U[SBD.s2]*SBD.U[SBD.s2];
+         SBD.Us0Us0_Us1Us1_Us2Us2 = SBD.U[SBD.s0]*SBD.U[SBD.s0]+
+             SBD.U[SBD.s1]*SBD.U[SBD.s1]+SBD.U[SBD.s2]*SBD.U[SBD.s2];
+	     ClipSurfaceBond(s->x,s->y,s->z,d->x,d->y,d->z,
+                 sc,dc, s->irad,d->irad, iProbeRad, sbptr->altl);
+	   }
+     }
+
 }
 
 
@@ -1425,7 +1497,7 @@ static void DisplaySelected( void )
     register int irad,sc,dc;
     register int col;
 
-    irad = (int)(Scale*20);
+    irad = (int)rint(Scale*20);
 
     if( irad>0 )
     {   ForEachBond
@@ -1452,7 +1524,7 @@ static void DisplaySelected( void )
 	}
 
 
-    irad = (int)(Scale*50);
+    irad = (int)rint(Scale*50);
     ForEachAtom
 	if( aptr->flag&NonBondFlag )
 	{   col = Shade2Colour( (aptr->flag&SelectFlag)? 1 : 0 );
@@ -1464,10 +1536,17 @@ static void DisplaySelected( void )
 static void RenderFrame( void )
 {
     register Chain __far *chain;
+    int dwf;
+
+    dwf = 0;
 
     if( !DisplayMode )
     {   if( DrawAtoms ) 
-	    DisplaySpaceFill();
+        DisplaySpaceFill();
+        if( DrawSurf ) {
+          DisplayWireframe();
+          dwf++;
+        }
         if( DrawStars )
             DisplayStars();
 
@@ -1475,7 +1554,10 @@ static void RenderFrame( void )
 	{   if( DrawBonds ) 
             {   if( DrawDoubleBonds )
                 {   DisplayDoubleBonds();
-                } else DisplayWireframe();
+                } else {
+                  if (!dwf) DisplayWireframe();
+                  dwf++;
+                }
             }
 
 	    if( DrawRibbon )
@@ -1542,6 +1624,8 @@ static void DrawFrameOne( void )
     /* Common View Elements */
     View.yskip = XRange;
     View.ymax = YRange;
+    View.fbuf = FBuffer;
+    View.dbuf = DBuffer;
 
     if( UseStereo )
     {
@@ -1549,9 +1633,9 @@ static void DrawFrameOne( void )
         wide = XRange>>1;
 
         /* Create 'Left' View structure */
-        View.fbuf = FBuffer;
-        View.dbuf = DBuffer;
+        View.shift = 0;
         View.xmax = wide;
+        View.offmax = 2*wide*YRange;
 
         DialValue[DialRY] -= temp;
         ReDrawFlag |= RFRotateY;
@@ -1559,9 +1643,9 @@ static void DrawFrameOne( void )
         RenderFrame();
 
         /* Create 'Right' View structure */
-        View.fbuf = FBuffer+wide;
-        View.dbuf = DBuffer+wide;
+        View.shift = wide;
         View.xmax = wide;
+        View.offmax = 2*wide*YRange;
 
         DialValue[DialRY] += temp;
         ReDrawFlag |= RFRotateY;
@@ -1570,9 +1654,9 @@ static void DrawFrameOne( void )
 
     } else /* Mono */
     {   /* Create 'Mono' View structure */
-        View.fbuf = FBuffer;
-        View.dbuf = DBuffer;
+        View.shift = 0;
         View.xmax = XRange;
+        View.offmax = XRange*YRange;
         RenderFrame();
     }
 
@@ -1712,24 +1796,28 @@ static void IdentifyAtom( int xpos, int ypos )
 	    }
 
 	    if( aptr->flag & (SphereFlag | StarFlag) )
-	    {   dy = AbsFun(aptr->y-ypos);
-		if( dy>aptr->irad ) continue;
-		rad = LookUp[aptr->irad][dy];
+	    {   int xrad;
+
+                xrad = aptr->irad;
+                if (aptr->flag&ExpandFlag) xrad+=iProbeRad;
+                dy = AbsFun(aptr->y-ypos);
+		if( dy > xrad ) continue;
+		rad = pythag(xrad,dy);
 		dx = AbsFun(aptr->x-xpos);
 		if( dx>rad ) continue;
 
 		new = False;
-		dpth = aptr->z+LookUp[rad][dx];
+		dpth = aptr->z+pythag(rad,dx);
 		if( UseSlabPlane && (aptr->z+rad>=SlabValue) )
 		{   dz = SlabValue-aptr->z;
 		    if( SlabMode && (dz >= -rad) )
-		    {   wide = LookUp[aptr->irad][AbsFun(dz)];
-			if( (dy<=wide) && (dx<=(int)(LookUp[wide][dy])) )
+		    {   wide = pythag(aptr->irad,AbsFun(dz));
+			if( (dy<=wide) && (dx<=pythag(wide,dy)) )
 			{   if( SlabMode == SlabFinal )
 			    {   dpth = SliceValue;
 				new = True;
 			    } else if( SlabMode == SlabHollow )
-			    {   dpth = aptr->z-LookUp[rad][dx];
+			    {   dpth = aptr->z-pythag(rad,dx);
 				new = !IdentFound || (dpth>IdentDepth);
 			    } else if( SlabMode != SlabHalf )
 			    {   /* SlabClose, SlabSection */
@@ -1831,6 +1919,12 @@ static void DescribeAtom( AtomRef *ptr, int flag )
     for( i=0; str[i] && i<12; i++ )
         if( str[i]!=' ' ) 
              WriteChar(str[i]);
+        
+    if (ptr->atm->model) 
+    {
+    	sprintf(buffer,"/%d",ptr->atm->model);
+    	WriteString(buffer);
+    }
 
     if( flag )
     {   sprintf(buffer," (%ld)",ptr->atm->serno);
@@ -1843,7 +1937,7 @@ int PickAtoms( int shift, int xpos, int ypos )
 {
     register AtomRef *ptr;
     register Label *label;
-    register float temp;
+    register double temp;
     register char *str;
     register size_t len;
 
@@ -1924,7 +2018,7 @@ int PickAtoms( int shift, int xpos, int ypos )
            y = (double)(QAtom->yorg + QAtom->fyorg + OrigCY)/250.0
                +(double)(QAtom->ytrl)/10000.0;
            z = (double)(QAtom->zorg + QAtom->fzorg + OrigCZ)/250.0
-               -(double)(QAtom->ztrl)/10000.0;
+               +(double)(QAtom->ztrl)/10000.0;
 
 #ifdef INVERT
            sprintf(buffer, "  Coordinates: %9.3f %9.3f %9.3f\n",x,-y,-z);
@@ -2064,21 +2158,21 @@ int PickAtoms( int shift, int xpos, int ypos )
 	    if ( PickMode != PickMonit )
 	        DeleteMonitors();
 	    if( PickMode == PickDist )
-            {   temp = (float)CalcDistance(PickHist[0].atm,
+            {   temp = (double)CalcDistance(PickHist[0].atm,
                                            PickHist[1].atm);
 
                 WriteString("Distance ");
                 DescribeAtom(PickHist,False);
                 WriteChar('-');
                 DescribeAtom(PickHist+1,False);
-                sprintf(buffer,": %.3f\n\n",temp);
+                sprintf(buffer,": %.2f\n\n",temp);
                 WriteString(buffer);
 		/* [GSG 11/21/95] */
 		AddMonitors(PickHist[0].atm, QAtom);
 	        ReDrawFlag |= RFRefresh;
 
             } else if( PickMode == PickAngle )
-            {   temp = (float)CalcAngle(PickHist[0].atm,
+            {   temp = (double)CalcAngle(PickHist[0].atm,
                                         PickHist[1].atm,
                                         PickHist[2].atm);
 
@@ -2088,18 +2182,18 @@ int PickAtoms( int shift, int xpos, int ypos )
                 DescribeAtom(PickHist+1,False);
                 WriteChar('-');
                 DescribeAtom(PickHist+2,False);
-                sprintf(buffer,": %.1f\n\n",temp);
+                sprintf(buffer,": %.2f\n\n",temp);
                 WriteString(buffer);
 
 		/* [GSG 11/21/95] */
 		AddMonitors2(PickHist[0].atm, PickHist[2].atm,
                   PickHist[1].atm, (RAtom __far *)NULL,
-		  (unsigned short) (temp*100), 128, PickAngle);
+		  (Long) (rint(temp*100)), 128, PickAngle);
 		ReDrawFlag |= RFRefresh;
 
 
             } else /* PickMode == PickTorsn */
-            {   temp = (float)CalcTorsion(PickHist[0].atm,
+            {   temp = (double)CalcTorsion(PickHist[0].atm,
                                           PickHist[1].atm,
                                           PickHist[2].atm,
                                           PickHist[3].atm);
@@ -2112,14 +2206,14 @@ int PickAtoms( int shift, int xpos, int ypos )
                 DescribeAtom(PickHist+2,False);
                 WriteChar('-');
                 DescribeAtom(PickHist+3,False);
-                sprintf(buffer,": %.1f\n\n",temp);
+                sprintf(buffer,": %.2f\n\n",temp);
                 WriteString(buffer);
                 WriteString(buffer);
 
 		/* [GSG 11/21/95] */
 	        AddMonitors2(PickHist[0].atm, PickHist[3].atm,
                   PickHist[1].atm, PickHist[2].atm,
-			     (unsigned short) (temp*100), 128, PickTorsn);
+		     (Long) (rint(temp*100)), 128, PickTorsn);
 		ReDrawFlag |= RFRefresh;
             }
         }
@@ -2146,6 +2240,7 @@ void ResetRenderer( void )
     DrawBonds = False;  MaxBondRadius = 0;
     DrawStars = False;
     DrawRibbon = False;
+    DrawSurf = False;
 
     SlabMode = SlabClose;
     UseSlabPlane = False;
