@@ -1,9 +1,10 @@
+
 /***************************************************************************
- *                            RasMol 2.7.2.1.1                             *
+ *                               RasMol 2.7.3                              *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                            26 January 2004                              *
+ *                             6 February 2005                             *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -25,12 +26,19 @@
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
+ *                   RasMol 2.7.3   Feb 05                                 *
+ *                                                                         *
+ *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
+ *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
+ *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
+ *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
+ *of Energy.                                                               *
  *                                                                         *
  *                    and Incorporating Translations by                    *
  *  Author                               Item                      Language*
- *  Isabel Servn Martnez,                                                *
- *  Jos Miguel Fernndez Fernndez      2.6   Manual              Spanish *
- *  Jos Miguel Fernndez Fernndez      2.7.1 Manual              Spanish *
+ *  Isabel Servan Martinez,                                                *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
  *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
  *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
@@ -39,35 +47,12 @@
  *                             This Release by                             *
  * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2001               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2005               *
  *                                                                         *
- * Please read the file NOTICE for important notices which apply to this   *
- * package. If you are not going to make changes to RasMol, you are not    * 
- * only permitted to freely make copies and distribute them, you are       * 
- * encouraged to do so, provided you do the following:                     *
- *   * 1. Either include the complete documentation, especially the file   *
- *     NOTICE, with what you distribute or provide a clear indication      *
- *     where people can get a copy of the documentation; and               *
- *   * 2. Please give credit where credit is due citing the version and    * 
- *     original authors properly; and                                      *  
- *   * 3. Please do not give anyone the impression that the original       *   
- *     authors are providing a warranty of any kind.                       *
- *                                                                         *
- * If you would like to use major pieces of RasMol in some other program,  *
- * make modifications to RasMol, or in some other way make what a lawyer   *
- * would call a "derived work", you are not only permitted to do so, you   *
- * are encouraged to do so. In addition to the things we discussed above,  *
- * please do the following:                                                *
- *   * 4. Please explain in your documentation how what you did differs    *
- *     from this version of RasMol; and                                    *
- *   * 5. Please make your modified source code available.                 *
- *                                                                         *
- * This version of RasMol is not in the public domain, but it is given     *
- * freely to the community in the hopes of advancing science. If you make  *
- * changes, please make them in a responsible manner, and please offer us  *
- * the opportunity to include those changes in future versions of RasMol.  *
+ *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
+ *Please read the file NOTICE for important notices which apply to this    *
+ *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
-
 /* repres.c
  $Log: repres.c,v $
  Revision 1.1  2004/05/07 19:46:16  yaya
@@ -152,7 +137,6 @@
 #endif
 
 /* These define light source position */
-#define LightDot(x,y,z)  ((x)+(y)+(z)+(z))
 #define LightLength      RootSix
 
 
@@ -539,7 +523,7 @@ void DeleteMonitors( void )
 /* [GSG 11/21/95] AddMonitors2 can add a monitor w/a given number */
 void AddMonitors2( RAtom __far *src, RAtom __far *dst,
       RAtom __far *mid1, RAtom __far *mid2,
-     unsigned short dist, unsigned char units, int monmode )
+      Long dist, unsigned char units, int monmode )
 {
     register Monitor **prev;
     register Monitor *ptr;
@@ -583,17 +567,9 @@ void AddMonitors2( RAtom __far *src, RAtom __far *dst,
 
 void AddMonitors( RAtom __far *src, RAtom __far *dst )
 {
-    register Long dx, dy, dz;
-    register Long dist;
-    unsigned short temp;
+    Long temp;
  
-    dx = src->xorg - dst->xorg + src->fxorg - dst->fxorg;
-    dy = src->yorg - dst->yorg + src->fyorg - dst->fyorg;
-    dz = src->zorg - dst->zorg + src->fzorg - dst->fzorg;
-
-    /* ptr->dist = 100.0*CalcDistance(src,dst) */
-    dist = isqrt( dx*dx + dy*dy + dz*dz );
-    temp = (unsigned short)((dist<<1)/5);
+    temp = (Long)rint(100.0*CalcDistance(src,dst));
 
     AddMonitors2(src, dst, 
       (RAtom __far *)NULL, (RAtom __far *)NULL, temp, 127, PickDist);
@@ -818,7 +794,7 @@ static void CheckVDWDot(  Long x,  Long y,  Long z, int col )
         {   aptr = item->data;
             if( !ProbeRadius )
             {   rad = ElemVDWRadius(aptr->elemno);
-            } else rad = ProbeRadius;
+            } else rad = ElemVDWRadius(aptr->elemno)+ProbeRadius;
             rad = rad*rad;
  
             /* Optimized Test! */
@@ -920,7 +896,7 @@ static void AddElemDots( int elem, int density )
  
     if( SolventDots || !ProbeRadius )
     {   rad = ElemVDWRadius(elem);
-    } else rad = ProbeRadius;
+    } else rad = ElemVDWRadius(elem)+ProbeRadius;
  
     count = (int)(((Long)density*rad*rad)/((Long)250*250));
     ptr = (DotVector __far*)_fmalloc(count*sizeof(DotVector));
@@ -932,7 +908,7 @@ static void AddElemDots( int elem, int density )
         temp = rad + ProbeRadius;
     } else probe = NULL;
  
-    equat = (int)sqrt(PI*count);
+    equat = (int)rint(sqrt(PI*count));
     if( !(vert=equat>>1) )
         vert = 1;
  
@@ -940,7 +916,7 @@ static void AddElemDots( int elem, int density )
     for( j=0; (i<count) && (j<vert); j++ )
     {   p = (PI*j)/(Real)vert;
         z = cos(p);  xy = sin(p);
-        horz = (int)(equat*xy);
+        horz = (int)rint(equat*xy);
         if( !horz ) horz = 1;
  
         for( k=0; (i<count) && (k<horz); k++ )
@@ -948,13 +924,13 @@ static void AddElemDots( int elem, int density )
             x = xy*sin(q);
             y = xy*cos(q);
  
-            ptr[i].dx = (int)(rad*x);
-            ptr[i].dy = (int)(rad*y);
-            ptr[i].dz = (int)(rad*z);
+            ptr[i].dx = (int)rint(rad*x);
+            ptr[i].dy = (int)rint(rad*y);
+            ptr[i].dz = (int)rint(rad*z);
             if( probe )
-            {   probe[i].dx = (int)(temp*x);
-                probe[i].dy = (int)(temp*y);
-                probe[i].dz = (int)(temp*z);
+            {   probe[i].dx = (int)rint(temp*x);
+                probe[i].dy = (int)rint(temp*y);
+                probe[i].dz = (int)rint(temp*z);
             }
             i++;
         }
@@ -970,8 +946,12 @@ static void FreeElemDots( void )
     register int i;
  
     for( i=0; i<MAXELEMNO; i++ )
-        if( ElemDots[i].count )
+        if( ElemDots[i].count ) {
             _ffree( ElemDots[i].dots );
+            if ( ElemDots[i].probe ) {
+              _ffree( ElemDots[i].probe );
+            }
+        }
     _ffree( ElemDots );
 }
  
@@ -1096,9 +1076,9 @@ void DisplaySurface( void )
     register int i;
     register int Cenx,Ceny,Cenz;
     
-    Cenx=(int)(CenX*MatX[0]+CenY*MatX[1]+CenZ*MatX[2]);
-	Ceny=(int)(CenX*MatY[0]+CenY*MatY[1]+CenZ*MatY[2]);
-	Cenz=(int)(CenX*MatZ[0]+CenY*MatZ[1]+CenZ*MatZ[2]);
+    Cenx=(int)rint(CenX*MatX[0]+CenY*MatX[1]+CenZ*MatX[2]);
+    Ceny=(int)rint(CenX*MatY[0]+CenY*MatY[1]+CenZ*MatY[2]);
+    Cenz=(int)rint(CenX*MatZ[0]+CenY*MatZ[1]+CenZ*MatZ[2]);
 
  
     for( ptr=DotPtr; ptr; ptr=ptr->next )
@@ -1107,11 +1087,11 @@ void DisplaySurface( void )
             y = ptr->ypos[i];
             z = ptr->zpos[i];
  
-            xi = (int)(x*MatX[0]+y*MatX[1]+z*MatX[2])+XOffset-Cenx;
+            xi = (int)rint(x*MatX[0]+y*MatX[1]+z*MatX[2])+XOffset-Cenx;
             if( XValid(xi) )
-            {   yi = (int)(x*MatY[0]+y*MatY[1]+z*MatY[2])+YOffset-Ceny;
+            {   yi = (int)rint(x*MatY[0]+y*MatY[1]+z*MatY[2])+YOffset-Ceny;
                 if( YValid(yi) )
-                {   zi = (int)(x*MatZ[0]+y*MatZ[1]+z*MatZ[2])+ZOffset-Cenz;
+                {   zi = (int)rint(x*MatZ[0]+y*MatZ[1]+z*MatZ[2])+ZOffset-Cenz;
                     if( ZValid(zi) && ZBack(zi) )
                         PlotDeepPoint(xi,yi,zi,ptr->col[i]);
                 }
