@@ -1,9 +1,10 @@
+
 /***************************************************************************
- *                            RasMol 2.7.2.1.1                             *
+ *                               RasMol 2.7.3                              *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                            26 January 2004                              *
+ *                             6 February 2005                             *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -25,12 +26,19 @@
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
+ *                   RasMol 2.7.3   Feb 05                                 *
+ *                                                                         *
+ *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
+ *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
+ *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
+ *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
+ *of Energy.                                                               *
  *                                                                         *
  *                    and Incorporating Translations by                    *
  *  Author                               Item                      Language*
- *  Isabel Servn Martnez,                                                *
- *  Jos Miguel Fernndez Fernndez      2.6   Manual              Spanish *
- *  Jos Miguel Fernndez Fernndez      2.7.1 Manual              Spanish *
+ *  Isabel Servan Martinez,                                                *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
  *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
  *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
@@ -39,35 +47,12 @@
  *                             This Release by                             *
  * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2001               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2005               *
  *                                                                         *
- * Please read the file NOTICE for important notices which apply to this   *
- * package. If you are not going to make changes to RasMol, you are not    * 
- * only permitted to freely make copies and distribute them, you are       * 
- * encouraged to do so, provided you do the following:                     *
- *   * 1. Either include the complete documentation, especially the file   *
- *     NOTICE, with what you distribute or provide a clear indication      *
- *     where people can get a copy of the documentation; and               *
- *   * 2. Please give credit where credit is due citing the version and    * 
- *     original authors properly; and                                      *  
- *   * 3. Please do not give anyone the impression that the original       *
- *     authors are providing a warranty of any kind.                       *
- *                                                                         *
- * If you would like to use major pieces of RasMol in some other program,  *
- * make modifications to RasMol, or in some other way make what a lawyer   *
- * would call a "derived work", you are not only permitted to do so, you   *
- * are encouraged to do so. In addition to the things we discussed above,  *
- * please do the following:                                                *
- *   * 4. Please explain in your documentation how what you did differs    *
- *     from this version of RasMol; and                                    *
- *   * 5. Please make your modified source code available.                 *
- *                                                                         *
- * This version of RasMol is not in the public domain, but it is given     *
- * freely to the community in the hopes of advancing science. If you make  *
- * changes, please make them in a responsible manner, and please offer us  *
- * the opportunity to include those changes in future versions of RasMol.  *
+ *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
+ *Please read the file NOTICE for important notices which apply to this    *
+ *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
-
 /* script.c
  $Log: script.c,v $
  Revision 1.1  2004/05/07 19:46:16  yaya
@@ -680,7 +665,7 @@ static void WriteScriptAtoms( void )
     register RAtom __far *aptr;
     register Long first=0,last=0;
     register int same,init;
-    register int cpk=0,vdw=0;
+    register int cpk=0,cpknew=0,vdw=0;
     register int col=0,rad=0;
     register int prevflag,staron,sphereon;
 
@@ -693,24 +678,34 @@ static void WriteScriptAtoms( void )
         if( !init )
         {   first = last = aptr->serno;
             cpk = IsCPKColour( aptr );
+	        cpknew = IsCpkNewColour( aptr );
             col = aptr->col;
+            if (cpk || cpknew ) col = 0;
             init = True;
-        } else if( cpk && IsCPKColour(aptr) )
+        } else if( (cpk && IsCPKColour(aptr)) || 
+                   (cpknew && IsCpkNewColour(aptr)))
         {   last = aptr->serno;
             if( aptr->col != col )
                 col = 0;
         } else if( aptr->col == col )
         {   last = aptr->serno;
             cpk = False;
+            cpknew = False;
         } else if( aptr->col != col )
         {   WriteScriptBetween( first, last );
             if( !col )
-            {   fputs("colour atoms cpk\n",OutFile);
+            {   if (cpk) {
+                   fputs("colour atoms cpk\n",OutFile);
+                } else {
+                   fputs("colour atoms cpknew\n",OutFile);
+                }
             } else WriteScriptColour("atoms",col);
                 
             first = last = aptr->serno;
             cpk = IsCPKColour( aptr );
+            cpknew = IsCpkNewColour( aptr );
             col = aptr->col;
+            if (cpk || cpknew ) col = 0;
             same = False;
         } else last = aptr->serno; 
         
@@ -720,10 +715,17 @@ static void WriteScriptAtoms( void )
         } else WriteScriptAll();
 
         if( !col )
-        {   fputs("colour atoms cpk\n",OutFile);
+        {   if (cpk) {
+              fputs("colour atoms cpk\n",OutFile);
+            } else {
+               fputs("colour atoms cpknew\n",OutFile);
+            }
         } else WriteScriptColour("atoms",col);
     }
 
+    
+	    
+
     staron = False;
     sphereon = False;
     if( DrawAtoms || DrawStars )
@@ -1392,7 +1394,7 @@ static void OutputKinemageVector( RAtom __far *src,  RAtom __far *dst, int col )
         fprintf(OutFile," P %g %g %g\n", 
           (src->xorg + src->fxorg + src->xtrl/40. + OrigCX)/250.0, 
           RestoreY((src->yorg + src->fyorg + src->ytrl/40. + OrigCY))/250.0,
-          -(src->zorg + src->fzorg - src->ztrl/40. + OrigCZ)/250.0 );
+          -(src->zorg + src->fzorg + src->ztrl/40. + OrigCZ)/250.0 );
     }
 
     if( col1 != col2 )
@@ -1400,7 +1402,7 @@ static void OutputKinemageVector( RAtom __far *src,  RAtom __far *dst, int col )
           (src->xtrl + dst->xtrl)/40. + OrigCX + OrigCX)/500.0;
         y = (src->yorg + dst->yorg + src->fyorg + dst->fyorg +
           (src->ytrl + dst->ytrl)/40. + OrigCY + OrigCY)/500.0;
-        z = (src->zorg + dst->zorg + src->fzorg + dst->fzorg -
+        z = (src->zorg + dst->zorg + src->fzorg + dst->fzorg +
           (src->ztrl + dst->ztrl)/40. + OrigCZ + OrigCZ)/500.0;
 
         fprintf(OutFile,"{} L %g %g %g\n", x, RestoreY(y), -z );
@@ -1415,7 +1417,7 @@ static void OutputKinemageVector( RAtom __far *src,  RAtom __far *dst, int col )
     fprintf(OutFile," L %g %g %g\n", 
       (dst->xorg + dst->fxorg + dst->xtrl/40. + OrigCX)/250.0,
       RestoreY((dst->yorg + dst->fyorg + dst->ytrl/40. + OrigCY))/250.0,
-       -(dst->zorg + dst->fzorg - dst->ztrl/40. + OrigCZ)/250.0 );
+       -(dst->zorg + dst->fzorg + dst->ztrl/40. + OrigCZ)/250.0 );
 
     MagePrev = dst;
     MageCol = col2;
@@ -1832,7 +1834,7 @@ int WritePOVRayFile( char *name )
             y = (double)(aptr->yorg + aptr->fyorg)/250.0 
                 + (double)(aptr->ytrl)/10000.;
             z = (double)(aptr->zorg + aptr->fzorg)/250.0 
-                - (double)(aptr->ztrl)/10000.;
+                + (double)(aptr->ztrl)/10000.;
 #ifdef __STDC__
             fprintf(OutFile,"object {sphere {<%g, %g, %g> %g}\n",
 #else
@@ -1922,7 +1924,7 @@ static void WriteVRMLAtoms( void )
                     y = (double)(aptr->yorg + aptr->fyorg)/250.0
                       + (double)(aptr->ytrl)/10000.;
                     z = -(double)(aptr->zorg + aptr->fzorg)/250.0
-                      + (double)(aptr->ztrl)/10000.;
+                      - (double)(aptr->ztrl)/10000.;
 
                     fputs("    Translation { translation ",OutFile);
                     WriteVRMLTriple(x-ox,RestoreY(y-oy),z-oz);
@@ -2001,7 +2003,7 @@ static void WriteVRMLWireframe( void )
                 y = (double)(dst->yorg + dst->fyorg)/250.0
                   + (double)(dst->ytrl)/10000.;
                 z = -(double)(dst->zorg + dst->fzorg)/250.0
-                  + (double)(dst->ztrl)/10000.;
+                  - (double)(dst->ztrl)/10000.;
 
                 fputs("        ",OutFile);
                 WriteVRMLTriple(x,RestoreY(y),z);
@@ -2018,7 +2020,7 @@ static void WriteVRMLWireframe( void )
                       +(double)(src->ytrl + dst->ytrl)/20000.;
                 z = -(double)(src->zorg + dst->zorg +
                       src->fzorg + dst->fzorg)/500.0
-                      +(double)(src->ztrl + dst->ztrl)/20000.;
+                      -(double)(src->ztrl + dst->ztrl)/20000.;
                 
                 fputs("        ",OutFile);
                 WriteVRMLTriple(x,RestoreY(y),z);
