@@ -1,9 +1,10 @@
+
 /***************************************************************************
- *                            RasMol 2.7.2.1.1                             *
+ *                               RasMol 2.7.3                              *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                            26 January 2004                              *
+ *                             6 February 2005                             *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -25,12 +26,19 @@
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
+ *                   RasMol 2.7.3   Feb 05                                 *
+ *                                                                         *
+ *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
+ *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
+ *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
+ *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
+ *of Energy.                                                               *
  *                                                                         *
  *                    and Incorporating Translations by                    *
  *  Author                               Item                      Language*
- *  Isabel Servn Martnez,                                                *
- *  Jos Miguel Fernndez Fernndez      2.6   Manual              Spanish *
- *  Jos Miguel Fernndez Fernndez      2.7.1 Manual              Spanish *
+ *  Isabel Servan Martinez,                                                *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
  *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
  *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
@@ -39,35 +47,12 @@
  *                             This Release by                             *
  * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2001               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2005               *
  *                                                                         *
- * Please read the file NOTICE for important notices which apply to this   *
- * package. If you are not going to make changes to RasMol, you are not    *
- * only permitted to freely make copies and distribute them, you are       *
- * encouraged to do so, provided you do the following:                     *
- *   * 1. Either include the complete documentation, especially the file   *
- *     NOTICE, with what you distribute or provide a clear indication      *
- *     where people can get a copy of the documentation; and               *
- *   * 2. Please give credit where credit is due citing the version and    *
- *     original authors properly; and                                      *
- *   * 3. Please do not give anyone the impression that the original       *
- *     authors are providing a warranty of any kind.                       *
- *                                                                         *
- * If you would like to use major pieces of RasMol in some other program,  *
- * make modifications to RasMol, or in some other way make what a lawyer   *
- * would call a "derived work", you are not only permitted to do so, you   *
- * are encouraged to do so. In addition to the things we discussed above,  *
- * please do the following:                                                *
- *   * 4. Please explain in your documentation how what you did differs    *
- *     from this version of RasMol; and                                    *
- *   * 5. Please make your modified source code available.                 *
- *                                                                         *
- * This version of RasMol is not in the public domain, but it is given     *
- * freely to the community in the hopes of advancing science. If you make  *
- * changes, please make them in a responsible manner, and please offer us  *
- * the opportunity to include those changes in future versions of RasMol.  *
+ *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
+ *Please read the file NOTICE for important notices which apply to this    *
+ *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
-
 /* x11win.c
  $Log: x11win.c,v $
  Revision 1.1  2004/05/07 19:46:16  yaya
@@ -186,7 +171,7 @@ static MenuItem FilMenu[11] = {
     { &(MolNStr[4]),                            0x01,  0, 
         &MolNLen[4],            &MoleculeIndex, 4 } };
 
-static MenuItem DisMenu[8] = {
+static MenuItem DisMenu[9] = {
     { &MsgStrs[StrMWirefr] /* "Wireframe"    */,     0x11,  &MsgAuxl[StrMWirefr],
         &MsgLens[StrMWirefr],    NULL, 0     },
     { &MsgStrs[StrMBackbn] /* "Backbone"     */,     0x11,  &MsgAuxl[StrMBackbn],
@@ -202,7 +187,10 @@ static MenuItem DisMenu[8] = {
     { &MsgStrs[StrMStrands]/* "Strands"      */,     0x11,  &MsgAuxl[StrMStrands],
         &MsgLens[StrMStrands],   NULL, 0     },
     { &MsgStrs[StrMCartoon]/* "Cartoons"     */,     0x11,  &MsgAuxl[StrMCartoon],
-        &MsgLens[StrMCartoon],   NULL, 0     }};
+        &MsgLens[StrMCartoon],   NULL, 0     },
+    { &MsgStrs[StrMMolSurf]/* "Molecular Surface"    */,     0x11,  &MsgAuxl[StrMMolSurf],
+        &MsgLens[StrMMolSurf],   NULL, 0     }};
+ 
 
 
 static MenuItem ColMenu[10] = {
@@ -308,7 +296,7 @@ typedef struct _BarItem {
 static BarItem MenuBar[MenuBarMax] = { 
     { FilMenu,  &MsgStrs[StrMFile]    /* "File"     */,  5, 0x01,&MsgAuxl[StrMFile],
         &MsgLens[StrMFile], &NumMolecules},
-    { DisMenu,  &MsgStrs[StrMDisplay] /* "Display"  */,  8, 0x01,&MsgAuxl[StrMDisplay],
+    { DisMenu,  &MsgStrs[StrMDisplay] /* "Display"  */,  9, 0x01,&MsgAuxl[StrMDisplay],
         &MsgLens[StrMDisplay], NULL },
     { ColMenu,  &MsgStrs[StrMColour]  /* "Colours"  */, 10, 0x01,&MsgAuxl[StrMColour],
         &MsgLens[StrMColour], NULL },
@@ -397,7 +385,8 @@ static unsigned long Ident[256];
 static int IdentCount;
 #endif
 
-static int HeldStep;
+static int XHeldButton;
+static int XHeldStep;
 
 static Byte Intensity[LutSize];
 static Pixel WhiteCol;
@@ -1778,7 +1767,7 @@ int OpenDisplay( int x, int y )
     UseHourGlass = True;
     DisableMenu = False;
     Monochrome = False;
-    HeldButton = -1;
+    XHeldButton = -1;
 
     for( i=0; i<8; i++ )
          DialValue[i] = 0.0;
@@ -2333,8 +2322,8 @@ static void DoneEvents( void )
     register Real temp;
     register int index;
 
-    if( HeldButton == YScrlDial )
-    {   index = NewScrlY+HeldStep;
+    if( XHeldButton == YScrlDial )
+    {   index = NewScrlY+XHeldStep;
 #ifdef ORIG
         if( YScrlDial < 3 )
         {   if( index<16 )             
@@ -2366,8 +2355,8 @@ static void DoneEvents( void )
         ScrlY = NewScrlY;
     }
 
-    if( HeldButton == XScrlDial )
-    {   index = NewScrlX+HeldStep;
+    if( XHeldButton == XScrlDial )
+    {   index = NewScrlX+XHeldStep;
 #ifdef ORIG
         if( XScrlDial<3 )
         {   if( index < 16 ) 
@@ -2420,7 +2409,7 @@ static int ProcessEvent(  XEvent *event )
     {   case(ButtonPress):
             {   XButtonPressedEvent *ptr;
 
-                HeldButton = -1;
+                XHeldButton = -1;
                 ptr = (XButtonPressedEvent*)event;
 
                 if( ptr->window==CanvWin )
@@ -2433,11 +2422,11 @@ static int ProcessEvent(  XEvent *event )
                 } else if( ptr->window==XScrlWin )
                 {   ReDrawFlag |= RFRotateY;
                     if( ptr->x<16 )
-                    {   HeldButton = XScrlDial;
-                        HeldStep = -XScrlSkip;
+                    {   XHeldButton = XScrlDial;
+                        XHeldStep = -XScrlSkip;
                     } else if( ptr->x>=XRange-16 )
-                    {   HeldButton = XScrlDial;
-                        HeldStep = XScrlSkip;
+                    {   XHeldButton = XScrlDial;
+                        XHeldStep = XScrlSkip;
                     } else
                     {   index = ptr->x-8;
 #ifdef ORIG
@@ -2460,11 +2449,11 @@ static int ProcessEvent(  XEvent *event )
                 } else if( ptr->window==YScrlWin )
                 {   ReDrawFlag |= RFRotateX;
                     if( ptr->y<16 )
-                    {   HeldButton = YScrlDial;
-                        HeldStep = -YScrlSkip;
+                    {   XHeldButton = YScrlDial;
+                        XHeldStep = -YScrlSkip;
                     } else if( ptr->y>=YRange-16 )
-                    {   HeldButton = YScrlDial;
-                        HeldStep = YScrlSkip;
+                    {   XHeldButton = YScrlDial;
+                        XHeldStep = YScrlSkip;
                     } else
                     {   index = ptr->y-8;
 #ifdef ORIG
@@ -2494,7 +2483,7 @@ static int ProcessEvent(  XEvent *event )
                 if( ptr->window==CanvWin )
                 {   stat = GetStatus(ptr->state);
                     ProcessMouseMove(ptr->x,ptr->y,stat);
-                } else if( HeldButton == -1 )
+                } else if( XHeldButton == -1 )
                 {   if( ptr->window==XScrlWin )
                     {   index = ptr->x-8;
                         NewScrlX = CropRange(index,16,XRange-32);
@@ -2508,9 +2497,9 @@ static int ProcessEvent(  XEvent *event )
         case(ButtonRelease):
             {   XButtonReleasedEvent *ptr;
 
-                if( HeldButton != -1 )
+                if( XHeldButton != -1 )
                 {   /* Three button emulation fix! */
-                    DoneEvents();  HeldButton = -1;
+                    DoneEvents();  XHeldButton = -1;
                 }
 
                 ptr = (XButtonReleasedEvent*)event;
@@ -2683,7 +2672,7 @@ static int HandleMenuLoop( void )
                  GrabModeAsync,GrabModeAsync,
                  None,None,CurrentTime);
 
-    HeldButton = -1;
+    XHeldButton = -1;
     MenuFocus = True;
     DrawMenuBar();
 
@@ -2824,7 +2813,7 @@ int FetchEvent( int wait )
     NewScrlX = ScrlX;
     NewScrlY = ScrlY;
 
-    if( HeldButton != -1 ) wait = False;
+    if( XHeldButton != -1 ) wait = False;
     while( XPending(dpy) || (wait && !ReDrawFlag) )
     {   XNextEvent( dpy, &event );
         result = ProcessEvent(&event);
